/* DataImportsPluginHost.c generated by valac 0.40.4, the Vala compiler
 * generated from DataImportsPluginHost.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */


#include <glib.h>
#include <glib-object.h>
#include "shotwell-plugin-dev-1.0.h"
#include <float.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <time.h>
#include <gobject/gvaluecollector.h>


#define SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER (spit_data_imports_core_importer_get_type ())
#define SPIT_DATA_IMPORTS_CORE_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporter))
#define SPIT_DATA_IMPORTS_CORE_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporterClass))
#define SPIT_DATA_IMPORTS_IS_CORE_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER))
#define SPIT_DATA_IMPORTS_IS_CORE_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER))
#define SPIT_DATA_IMPORTS_CORE_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporterClass))

typedef struct _SpitDataImportsCoreImporter SpitDataImportsCoreImporter;
typedef struct _SpitDataImportsCoreImporterClass SpitDataImportsCoreImporterClass;
typedef struct _SpitDataImportsCoreImporterPrivate SpitDataImportsCoreImporterPrivate;

#define TYPE_BATCH_IMPORT_ROLL (batch_import_roll_get_type ())
#define BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRoll))
#define BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))
#define IS_BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_ROLL))
#define IS_BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_ROLL))
#define BATCH_IMPORT_ROLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))

typedef struct _BatchImportRoll BatchImportRoll;
typedef struct _BatchImportRollClass BatchImportRollClass;
#define _batch_import_roll_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_roll_unref (var), NULL)))

#define TYPE_SORTED_LIST (sorted_list_get_type ())
#define SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SORTED_LIST, SortedList))
#define SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SORTED_LIST, SortedListClass))
#define IS_SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SORTED_LIST))
#define IS_SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SORTED_LIST))
#define SORTED_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SORTED_LIST, SortedListClass))

typedef struct _SortedList SortedList;
typedef struct _SortedListClass SortedListClass;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB (spit_data_imports_data_import_job_get_type ())
#define SPIT_DATA_IMPORTS_DATA_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJob))
#define SPIT_DATA_IMPORTS_DATA_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJobClass))
#define SPIT_DATA_IMPORTS_IS_DATA_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB))
#define SPIT_DATA_IMPORTS_IS_DATA_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB))
#define SPIT_DATA_IMPORTS_DATA_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJobClass))

typedef struct _SpitDataImportsDataImportJob SpitDataImportsDataImportJob;
typedef struct _SpitDataImportsDataImportJobClass SpitDataImportsDataImportJobClass;

#define SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE (spit_data_imports_data_import_source_get_type ())
#define SPIT_DATA_IMPORTS_DATA_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE, SpitDataImportsDataImportSource))
#define SPIT_DATA_IMPORTS_DATA_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE, SpitDataImportsDataImportSourceClass))
#define SPIT_DATA_IMPORTS_IS_DATA_IMPORT_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE))
#define SPIT_DATA_IMPORTS_IS_DATA_IMPORT_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE))
#define SPIT_DATA_IMPORTS_DATA_IMPORT_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_SOURCE, SpitDataImportsDataImportSourceClass))

typedef struct _SpitDataImportsDataImportSource SpitDataImportsDataImportSource;
typedef struct _SpitDataImportsDataImportSourceClass SpitDataImportsDataImportSourceClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _batch_import_job_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_job_unref (var), NULL)))
#define _spit_data_imports_data_import_source_unref0(var) ((var == NULL) ? NULL : (var = (spit_data_imports_data_import_source_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_BATCH_IMPORT (batch_import_get_type ())
#define BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT, BatchImport))
#define BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT, BatchImportClass))
#define IS_BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT))
#define IS_BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT))
#define BATCH_IMPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT, BatchImportClass))

typedef struct _BatchImport BatchImport;
typedef struct _BatchImportClass BatchImportClass;

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;
typedef struct _SpitDataImportsParamSpecCoreImporter SpitDataImportsParamSpecCoreImporter;

#define PLUGINS_TYPE_STANDARD_HOST_INTERFACE (plugins_standard_host_interface_get_type ())
#define PLUGINS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface))
#define PLUGINS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_STANDARD_HOST_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))

typedef struct _PluginsStandardHostInterface PluginsStandardHostInterface;
typedef struct _PluginsStandardHostInterfaceClass PluginsStandardHostInterfaceClass;
typedef struct _PluginsStandardHostInterfacePrivate PluginsStandardHostInterfacePrivate;

#define SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST (spit_data_imports_concrete_data_imports_host_get_type ())
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost))
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostClass))
#define SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostClass))

typedef struct _SpitDataImportsConcreteDataImportsHost SpitDataImportsConcreteDataImportsHost;
typedef struct _SpitDataImportsConcreteDataImportsHostClass SpitDataImportsConcreteDataImportsHostClass;
typedef struct _SpitDataImportsConcreteDataImportsHostPrivate SpitDataImportsConcreteDataImportsHostPrivate;

#define DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG (data_imports_ui_data_imports_dialog_get_type ())
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialog))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG))
#define DATA_IMPORTS_UI_DATA_IMPORTS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_DATA_IMPORTS_DIALOG, DataImportsUIDataImportsDialogClass))

typedef struct _DataImportsUIDataImportsDialog DataImportsUIDataImportsDialog;
typedef struct _DataImportsUIDataImportsDialogClass DataImportsUIDataImportsDialogClass;

#define DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE (data_imports_ui_concrete_dialog_pane_get_type ())
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPane))
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPaneClass))
#define DATA_IMPORTS_UI_IS_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE))
#define DATA_IMPORTS_UI_IS_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE))
#define DATA_IMPORTS_UI_CONCRETE_DIALOG_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_CONCRETE_DIALOG_PANE, DataImportsUIConcreteDialogPaneClass))

typedef struct _DataImportsUIConcreteDialogPane DataImportsUIConcreteDialogPane;
typedef struct _DataImportsUIConcreteDialogPaneClass DataImportsUIConcreteDialogPaneClass;

#define DATA_IMPORTS_UI_TYPE_PROGRESS_PANE (data_imports_ui_progress_pane_get_type ())
#define DATA_IMPORTS_UI_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPane))
#define DATA_IMPORTS_UI_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPaneClass))
#define DATA_IMPORTS_UI_IS_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE))
#define DATA_IMPORTS_UI_IS_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE))
#define DATA_IMPORTS_UI_PROGRESS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_PROGRESS_PANE, DataImportsUIProgressPaneClass))

typedef struct _DataImportsUIProgressPane DataImportsUIProgressPane;
typedef struct _DataImportsUIProgressPaneClass DataImportsUIProgressPaneClass;
enum  {
	SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_0_PROPERTY,
	SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_NUM_PROPERTIES
};
static GParamSpec* spit_data_imports_concrete_data_imports_host_properties[SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_NUM_PROPERTIES];
#define _spit_data_imports_core_importer_unref0(var) ((var == NULL) ? NULL : (var = (spit_data_imports_core_importer_unref (var), NULL)))

#define DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE (data_imports_ui_static_message_pane_get_type ())
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePane))
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePaneClass))
#define DATA_IMPORTS_UI_IS_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE))
#define DATA_IMPORTS_UI_IS_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE))
#define DATA_IMPORTS_UI_STATIC_MESSAGE_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_STATIC_MESSAGE_PANE, DataImportsUIStaticMessagePaneClass))

typedef struct _DataImportsUIStaticMessagePane DataImportsUIStaticMessagePane;
typedef struct _DataImportsUIStaticMessagePaneClass DataImportsUIStaticMessagePaneClass;

#define DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE (data_imports_ui_library_selection_pane_get_type ())
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPane))
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPaneClass))
#define DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE))
#define DATA_IMPORTS_UI_IS_LIBRARY_SELECTION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE))
#define DATA_IMPORTS_UI_LIBRARY_SELECTION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_UI_TYPE_LIBRARY_SELECTION_PANE, DataImportsUILibrarySelectionPaneClass))

typedef struct _DataImportsUILibrarySelectionPane DataImportsUILibrarySelectionPane;
typedef struct _DataImportsUILibrarySelectionPaneClass DataImportsUILibrarySelectionPaneClass;

#define SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST (spit_data_imports_welcome_data_imports_host_get_type ())
#define SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost))
#define SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHostClass))
#define SPIT_DATA_IMPORTS_IS_WELCOME_DATA_IMPORTS_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_IS_WELCOME_DATA_IMPORTS_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST))
#define SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHostClass))

typedef struct _SpitDataImportsWelcomeDataImportsHost SpitDataImportsWelcomeDataImportsHost;
typedef struct _SpitDataImportsWelcomeDataImportsHostClass SpitDataImportsWelcomeDataImportsHostClass;
typedef struct _SpitDataImportsWelcomeDataImportsHostPrivate SpitDataImportsWelcomeDataImportsHostPrivate;

#define SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST (spit_data_imports_welcome_import_meta_host_get_type ())
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHost))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostClass))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostClass))

typedef struct _SpitDataImportsWelcomeImportMetaHost SpitDataImportsWelcomeImportMetaHost;
typedef struct _SpitDataImportsWelcomeImportMetaHostClass SpitDataImportsWelcomeImportMetaHostClass;
enum  {
	SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_0_PROPERTY,
	SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_NUM_PROPERTIES
};
static GParamSpec* spit_data_imports_welcome_data_imports_host_properties[SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_NUM_PROPERTIES];

#define TYPE_WELCOME_SERVICE_ENTRY (welcome_service_entry_get_type ())
#define WELCOME_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntry))
#define IS_WELCOME_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_SERVICE_ENTRY))
#define WELCOME_SERVICE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntryIface))

typedef struct _WelcomeServiceEntry WelcomeServiceEntry;
typedef struct _WelcomeServiceEntryIface WelcomeServiceEntryIface;

#define SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY (spit_data_imports_welcome_import_service_entry_get_type ())
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntry))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntryClass))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_SERVICE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntryClass))

typedef struct _SpitDataImportsWelcomeImportServiceEntry SpitDataImportsWelcomeImportServiceEntry;
typedef struct _SpitDataImportsWelcomeImportServiceEntryClass SpitDataImportsWelcomeImportServiceEntryClass;
typedef struct _SpitDataImportsWelcomeImportServiceEntryPrivate SpitDataImportsWelcomeImportServiceEntryPrivate;
enum  {
	SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_0_PROPERTY,
	SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_NUM_PROPERTIES
};
static GParamSpec* spit_data_imports_welcome_import_service_entry_properties[SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_NUM_PROPERTIES];
typedef struct _SpitDataImportsWelcomeImportMetaHostPrivate SpitDataImportsWelcomeImportMetaHostPrivate;

#define TYPE_WELCOME_DIALOG (welcome_dialog_get_type ())
#define WELCOME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_DIALOG, WelcomeDialog))
#define WELCOME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WELCOME_DIALOG, WelcomeDialogClass))
#define IS_WELCOME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_DIALOG))
#define IS_WELCOME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WELCOME_DIALOG))
#define WELCOME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WELCOME_DIALOG, WelcomeDialogClass))

typedef struct _WelcomeDialog WelcomeDialog;
typedef struct _WelcomeDialogClass WelcomeDialogClass;
enum  {
	SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_0_PROPERTY,
	SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_NUM_PROPERTIES
};
static GParamSpec* spit_data_imports_welcome_import_meta_host_properties[SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_NUM_PROPERTIES];
typedef struct _ImportManifestPrivate ImportManifestPrivate;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_BATCH_IMPORT_RESULT (batch_import_result_get_type ())
#define BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResult))
#define BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))
#define IS_BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_RESULT))
#define IS_BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_RESULT))
#define BATCH_IMPORT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))

typedef struct _BatchImportResult BatchImportResult;
typedef struct _BatchImportResultClass BatchImportResultClass;
#define _import_manifest_unref0(var) ((var == NULL) ? NULL : (var = (import_manifest_unref (var), NULL)))
#define _batch_import_result_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_result_unref (var), NULL)))

#define IMPORT_UI_TYPE_QUESTION_PARAMS (import_ui_question_params_get_type ())
#define IMPORT_UI_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams))
#define IMPORT_UI_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))
#define IMPORT_UI_IS_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_IS_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_QUESTION_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))

typedef struct _ImportUIQuestionParams ImportUIQuestionParams;
typedef struct _ImportUIQuestionParamsClass ImportUIQuestionParamsClass;

struct _SpitDataImportsCoreImporter {
	GTypeInstance parent_instance;
	volatile int ref_count;
	SpitDataImportsCoreImporterPrivate * priv;
	gint imported_items_count;
	BatchImportRoll* current_import_roll;
};

struct _SpitDataImportsCoreImporterClass {
	GTypeClass parent_class;
	void (*finalize) (SpitDataImportsCoreImporter *self);
};

struct _SpitDataImportsCoreImporterPrivate {
	SpitDataImportsPluginHost* host;
};

typedef gint64 (*Comparator) (void* a, void* b, void* user_data);
typedef void (*BatchImportImportReporter) (ImportManifest* manifest, BatchImportRoll* import_roll, void* user_data);
struct _SpitDataImportsParamSpecCoreImporter {
	GParamSpec parent_instance;
};

struct _PluginsStandardHostInterface {
	GObject parent_instance;
	PluginsStandardHostInterfacePrivate * priv;
};

struct _PluginsStandardHostInterfaceClass {
	GObjectClass parent_class;
};

struct _SpitDataImportsConcreteDataImportsHost {
	PluginsStandardHostInterface parent_instance;
	SpitDataImportsConcreteDataImportsHostPrivate * priv;
};

struct _SpitDataImportsConcreteDataImportsHostClass {
	PluginsStandardHostInterfaceClass parent_class;
};

struct _SpitDataImportsConcreteDataImportsHostPrivate {
	SpitDataImportsDataImporter* active_importer;
	DataImportsUIDataImportsDialog* dialog;
	DataImportsUIProgressPane* progress_pane;
	gboolean importing_halted;
	SpitDataImportsCoreImporter* core_importer;
};

struct _SpitDataImportsWelcomeDataImportsHost {
	PluginsStandardHostInterface parent_instance;
	SpitDataImportsWelcomeDataImportsHostPrivate * priv;
};

struct _SpitDataImportsWelcomeDataImportsHostClass {
	PluginsStandardHostInterfaceClass parent_class;
};

struct _SpitDataImportsWelcomeDataImportsHostPrivate {
	SpitDataImportsWelcomeImportMetaHost* meta_host;
	SpitDataImportsDataImporter* active_importer;
	gboolean importing_halted;
	SpitDataImportsCoreImporter* core_importer;
};

struct _WelcomeServiceEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_service_name) (WelcomeServiceEntry* self);
	void (*execute) (WelcomeServiceEntry* self);
};

struct _SpitDataImportsWelcomeImportServiceEntry {
	GObject parent_instance;
	SpitDataImportsWelcomeImportServiceEntryPrivate * priv;
};

struct _SpitDataImportsWelcomeImportServiceEntryClass {
	GObjectClass parent_class;
};

struct _SpitDataImportsWelcomeImportServiceEntryPrivate {
	gchar* pluggable_name;
	SpitDataImportsImportableLibrary** discovered_libraries;
	gint discovered_libraries_length1;
	gint _discovered_libraries_size_;
	SpitDataImportsPluginHost* host;
};

struct _SpitDataImportsWelcomeImportMetaHost {
	GObject parent_instance;
	SpitDataImportsWelcomeImportMetaHostPrivate * priv;
};

struct _SpitDataImportsWelcomeImportMetaHostClass {
	GObjectClass parent_class;
};

struct _SpitDataImportsWelcomeImportMetaHostPrivate {
	WelcomeDialog* dialog;
};

struct _ImportManifest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportManifestPrivate * priv;
	GeeList* imported;
	GeeList* success;
	GeeList* camera_failed;
	GeeList* failed;
	GeeList* write_failed;
	GeeList* skipped_photos;
	GeeList* skipped_files;
	GeeList* aborted;
	GeeList* already_imported;
	GeeList* corrupt_files;
	GeeList* all;
	GTimer* timer;
};

struct _ImportManifestClass {
	GTypeClass parent_class;
	void (*finalize) (ImportManifest *self);
};


static gpointer spit_data_imports_core_importer_parent_class = NULL;
static gpointer spit_data_imports_concrete_data_imports_host_parent_class = NULL;
static SpitDataImportsPluginHostIface * spit_data_imports_concrete_data_imports_host_spit_data_imports_plugin_host_parent_iface = NULL;
static gpointer spit_data_imports_welcome_data_imports_host_parent_class = NULL;
static SpitDataImportsPluginHostIface * spit_data_imports_welcome_data_imports_host_spit_data_imports_plugin_host_parent_iface = NULL;
static gpointer spit_data_imports_welcome_import_service_entry_parent_class = NULL;
static WelcomeServiceEntryIface * spit_data_imports_welcome_import_service_entry_welcome_service_entry_parent_iface = NULL;
static gpointer spit_data_imports_welcome_import_meta_host_parent_class = NULL;
extern ImportManifest* spit_data_imports_meta_manifest;
ImportManifest* spit_data_imports_meta_manifest = NULL;

gpointer spit_data_imports_core_importer_ref (gpointer instance);
void spit_data_imports_core_importer_unref (gpointer instance);
GParamSpec* spit_data_imports_param_spec_core_importer (const gchar* name,
                                                        const gchar* nick,
                                                        const gchar* blurb,
                                                        GType object_type,
                                                        GParamFlags flags);
void spit_data_imports_value_set_core_importer (GValue* value,
                                                gpointer v_object);
void spit_data_imports_value_take_core_importer (GValue* value,
                                                 gpointer v_object);
gpointer spit_data_imports_value_get_core_importer (const GValue* value);
GType spit_data_imports_core_importer_get_type (void) G_GNUC_CONST;
gpointer batch_import_roll_ref (gpointer instance);
void batch_import_roll_unref (gpointer instance);
GParamSpec* param_spec_batch_import_roll (const gchar* name,
                                          const gchar* nick,
                                          const gchar* blurb,
                                          GType object_type,
                                          GParamFlags flags);
void value_set_batch_import_roll (GValue* value,
                                  gpointer v_object);
void value_take_batch_import_roll (GValue* value,
                                   gpointer v_object);
gpointer value_get_batch_import_roll (const GValue* value);
GType batch_import_roll_get_type (void) G_GNUC_CONST;
#define SPIT_DATA_IMPORTS_CORE_IMPORTER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporterPrivate))
SpitDataImportsCoreImporter* spit_data_imports_core_importer_new (SpitDataImportsPluginHost* host);
SpitDataImportsCoreImporter* spit_data_imports_core_importer_construct (GType object_type,
                                                                        SpitDataImportsPluginHost* host);
void spit_data_imports_core_importer_prepare_media_items_for_import (SpitDataImportsCoreImporter* self,
                                                                     SpitDataImportsImportableMediaItem** items,
                                                                     int items_length1,
                                                                     gdouble progress,
                                                                     gdouble host_progress_delta,
                                                                     const gchar* progress_message);
GType sorted_list_get_type (void) G_GNUC_CONST;
gpointer batch_import_job_ref (gpointer instance);
void batch_import_job_unref (gpointer instance);
GParamSpec* param_spec_batch_import_job (const gchar* name,
                                         const gchar* nick,
                                         const gchar* blurb,
                                         GType object_type,
                                         GParamFlags flags);
void value_set_batch_import_job (GValue* value,
                                 gpointer v_object);
void value_take_batch_import_job (GValue* value,
                                  gpointer v_object);
gpointer value_get_batch_import_job (const GValue* value);
GType batch_import_job_get_type (void) G_GNUC_CONST;
GType spit_data_imports_data_import_job_get_type (void) G_GNUC_CONST;
gint64 spit_data_imports_import_job_comparator (void* a,
                                                void* b);
static gint64 _spit_data_imports_import_job_comparator_comparator (void* a,
                                                            void* b,
                                                            gpointer self);
SortedList* sorted_list_new (GType g_type,
                             GBoxedCopyFunc g_dup_func,
                             GDestroyNotify g_destroy_func,
                             Comparator cmp,
                             void* cmp_target);
SortedList* sorted_list_construct (GType object_type,
                                   GType g_type,
                                   GBoxedCopyFunc g_dup_func,
                                   GDestroyNotify g_destroy_func,
                                   Comparator cmp,
                                   void* cmp_target);
gpointer spit_data_imports_data_import_source_ref (gpointer instance);
void spit_data_imports_data_import_source_unref (gpointer instance);
GParamSpec* spit_data_imports_param_spec_data_import_source (const gchar* name,
                                                             const gchar* nick,
                                                             const gchar* blurb,
                                                             GType object_type,
                                                             GParamFlags flags);
void spit_data_imports_value_set_data_import_source (GValue* value,
                                                     gpointer v_object);
void spit_data_imports_value_take_data_import_source (GValue* value,
                                                      gpointer v_object);
gpointer spit_data_imports_value_get_data_import_source (const GValue* value);
GType spit_data_imports_data_import_source_get_type (void) G_GNUC_CONST;
SpitDataImportsDataImportSource* spit_data_imports_data_import_source_new (SpitDataImportsImportableMediaItem* db_photo);
SpitDataImportsDataImportSource* spit_data_imports_data_import_source_construct (GType object_type,
                                                                                 SpitDataImportsImportableMediaItem* db_photo);
gboolean spit_data_imports_data_import_source_was_backing_file_found (SpitDataImportsDataImportSource* self);
gchar* spit_data_imports_data_import_source_get_filename (SpitDataImportsDataImportSource* self);
SpitDataImportsDataImportJob* spit_data_imports_data_import_job_new (SpitDataImportsDataImportSource* import_source);
SpitDataImportsDataImportJob* spit_data_imports_data_import_job_construct (GType object_type,
                                                                           SpitDataImportsDataImportSource* import_source);
gboolean spit_data_imports_data_import_source_is_already_imported (SpitDataImportsDataImportSource* self);
BatchImportRoll* batch_import_roll_new (void);
BatchImportRoll* batch_import_roll_construct (GType object_type);
GType batch_import_get_type (void) G_GNUC_CONST;
gpointer import_manifest_ref (gpointer instance);
void import_manifest_unref (gpointer instance);
GParamSpec* param_spec_import_manifest (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
void value_set_import_manifest (GValue* value,
                                gpointer v_object);
void value_take_import_manifest (GValue* value,
                                 gpointer v_object);
gpointer value_get_import_manifest (const GValue* value);
GType import_manifest_get_type (void) G_GNUC_CONST;
void spit_data_imports_data_import_reporter (ImportManifest* manifest,
                                             BatchImportRoll* import_roll);
static void _spit_data_imports_data_import_reporter_batch_import_import_reporter (ImportManifest* manifest,
                                                                           BatchImportRoll* import_roll,
                                                                           gpointer self);
BatchImport* batch_import_new (GeeIterable* jobs,
                               const gchar* name,
                               BatchImportImportReporter reporter,
                               void* reporter_target,
                               GeeArrayList* prefailed,
                               GeeArrayList* pre_already_imported,
                               GCancellable* cancellable,
                               BatchImportRoll* import_roll,
                               ImportManifest* skip_manifest);
BatchImport* batch_import_construct (GType object_type,
                                     GeeIterable* jobs,
                                     const gchar* name,
                                     BatchImportImportReporter reporter,
                                     void* reporter_target,
                                     GeeArrayList* prefailed,
                                     GeeArrayList* pre_already_imported,
                                     GCancellable* cancellable,
                                     BatchImportRoll* import_roll,
                                     ImportManifest* skip_manifest);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
GType library_window_get_type (void) G_GNUC_CONST;
LibraryWindow* library_window_get_app (void);
void library_window_enqueue_batch_import (LibraryWindow* self,
                                          BatchImport* batch_import,
                                          gboolean allow_user_cancel);
void spit_data_imports_core_importer_finalize_import (SpitDataImportsCoreImporter* self);
static void spit_data_imports_core_importer_finalize (SpitDataImportsCoreImporter * obj);
GType plugins_standard_host_interface_get_type (void) G_GNUC_CONST;
GType spit_data_imports_concrete_data_imports_host_get_type (void) G_GNUC_CONST;
GType data_imports_ui_data_imports_dialog_get_type (void) G_GNUC_CONST;
GType data_imports_ui_concrete_dialog_pane_get_type (void) G_GNUC_CONST;
GType data_imports_ui_progress_pane_get_type (void) G_GNUC_CONST;
#define SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHostPrivate))
SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_new (SpitDataImportsService* service,
                                                                                          DataImportsUIDataImportsDialog* dialog);
SpitDataImportsConcreteDataImportsHost* spit_data_imports_concrete_data_imports_host_construct (GType object_type,
                                                                                                SpitDataImportsService* service,
                                                                                                DataImportsUIDataImportsDialog* dialog);
PluginsStandardHostInterface* plugins_standard_host_interface_new (SpitPluggable* pluggable,
                                                                   const gchar* config_domain);
PluginsStandardHostInterface* plugins_standard_host_interface_construct (GType object_type,
                                                                         SpitPluggable* pluggable,
                                                                         const gchar* config_domain);
static SpitDataImportsDataImporter* spit_data_imports_concrete_data_imports_host_real_get_data_importer (SpitDataImportsPluginHost* base);
static void spit_data_imports_concrete_data_imports_host_real_start_importing (SpitDataImportsPluginHost* base);
static void spit_data_imports_concrete_data_imports_host_real_stop_importing (SpitDataImportsPluginHost* base);
static void spit_data_imports_concrete_data_imports_host_clean_up (SpitDataImportsConcreteDataImportsHost* self);
void spit_data_imports_concrete_data_imports_host_set_button_mode (SpitDataImportsConcreteDataImportsHost* self,
                                                                   SpitDataImportsPluginHostButtonMode mode);
void data_imports_ui_data_imports_dialog_set_close_button_mode (DataImportsUIDataImportsDialog* self);
void data_imports_ui_data_imports_dialog_set_cancel_button_mode (DataImportsUIDataImportsDialog* self);
static void spit_data_imports_concrete_data_imports_host_real_post_error (SpitDataImportsPluginHost* base,
                                                                   GError* err);
static void spit_data_imports_concrete_data_imports_host_real_post_error_message (SpitDataImportsPluginHost* base,
                                                                           const gchar* message);
void data_imports_ui_data_imports_dialog_install_pane (DataImportsUIDataImportsDialog* self,
                                                       SpitDataImportsDialogPane* pane);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_new_with_pango (const gchar* msg);
DataImportsUIStaticMessagePane* data_imports_ui_static_message_pane_construct_with_pango (GType object_type,
                                                                                          const gchar* msg);
GType data_imports_ui_static_message_pane_get_type (void) G_GNUC_CONST;
void data_imports_ui_data_imports_dialog_unlock_service (DataImportsUIDataImportsDialog* self);
static void spit_data_imports_concrete_data_imports_host_real_install_dialog_pane (SpitDataImportsPluginHost* base,
                                                                            SpitDataImportsDialogPane* pane,
                                                                            SpitDataImportsPluginHostButtonMode button_mode);
static void spit_data_imports_concrete_data_imports_host_real_install_static_message_pane (SpitDataImportsPluginHost* base,
                                                                                    const gchar* message,
                                                                                    SpitDataImportsPluginHostButtonMode button_mode);
static void spit_data_imports_concrete_data_imports_host_real_install_library_selection_pane (SpitDataImportsPluginHost* base,
                                                                                       const gchar* welcome_message,
                                                                                       SpitDataImportsImportableLibrary** discovered_libraries,
                                                                                       int discovered_libraries_length1,
                                                                                       const gchar* file_select_label);
DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_new (SpitDataImportsPluginHost* host,
                                                                               const gchar* welcome_message,
                                                                               SpitDataImportsImportableLibrary** discovered_libraries,
                                                                               int discovered_libraries_length1,
                                                                               const gchar* file_select_label);
DataImportsUILibrarySelectionPane* data_imports_ui_library_selection_pane_construct (GType object_type,
                                                                                     SpitDataImportsPluginHost* host,
                                                                                     const gchar* welcome_message,
                                                                                     SpitDataImportsImportableLibrary** discovered_libraries,
                                                                                     int discovered_libraries_length1,
                                                                                     const gchar* file_select_label);
GType data_imports_ui_library_selection_pane_get_type (void) G_GNUC_CONST;
static void spit_data_imports_concrete_data_imports_host_real_install_import_progress_pane (SpitDataImportsPluginHost* base,
                                                                                     const gchar* message);
DataImportsUIProgressPane* data_imports_ui_progress_pane_new (const gchar* message);
DataImportsUIProgressPane* data_imports_ui_progress_pane_construct (GType object_type,
                                                                    const gchar* message);
static void spit_data_imports_concrete_data_imports_host_real_update_import_progress_pane (SpitDataImportsPluginHost* base,
                                                                                    gdouble progress,
                                                                                    const gchar* progress_message);
void data_imports_ui_progress_pane_update_progress (DataImportsUIProgressPane* self,
                                                    gdouble progress,
                                                    const gchar* progress_message);
static void spit_data_imports_concrete_data_imports_host_real_prepare_media_items_for_import (SpitDataImportsPluginHost* base,
                                                                                       SpitDataImportsImportableMediaItem** items,
                                                                                       int items_length1,
                                                                                       gdouble progress,
                                                                                       gdouble host_progress_delta,
                                                                                       const gchar* progress_message);
static void spit_data_imports_concrete_data_imports_host_real_finalize_import (SpitDataImportsPluginHost* base,
                                                                        SpitDataImportsImportedItemsCountCallback report_imported_items_count,
                                                                        void* report_imported_items_count_target,
                                                                        const gchar* finalize_message);
void library_window_switch_to_import_queue_page (LibraryWindow* self);
static void spit_data_imports_concrete_data_imports_host_finalize (GObject * obj);
GType spit_data_imports_welcome_data_imports_host_get_type (void) G_GNUC_CONST;
GType spit_data_imports_welcome_import_meta_host_get_type (void) G_GNUC_CONST;
#define SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHostPrivate))
SpitDataImportsWelcomeDataImportsHost* spit_data_imports_welcome_data_imports_host_new (SpitDataImportsService* service,
                                                                                        SpitDataImportsWelcomeImportMetaHost* meta_host);
SpitDataImportsWelcomeDataImportsHost* spit_data_imports_welcome_data_imports_host_construct (GType object_type,
                                                                                              SpitDataImportsService* service,
                                                                                              SpitDataImportsWelcomeImportMetaHost* meta_host);
static SpitDataImportsDataImporter* spit_data_imports_welcome_data_imports_host_real_get_data_importer (SpitDataImportsPluginHost* base);
static void spit_data_imports_welcome_data_imports_host_real_start_importing (SpitDataImportsPluginHost* base);
static void spit_data_imports_welcome_data_imports_host_real_stop_importing (SpitDataImportsPluginHost* base);
static void spit_data_imports_welcome_data_imports_host_clean_up (SpitDataImportsWelcomeDataImportsHost* self);
static void spit_data_imports_welcome_data_imports_host_real_post_error (SpitDataImportsPluginHost* base,
                                                                  GError* err);
static void spit_data_imports_welcome_data_imports_host_real_post_error_message (SpitDataImportsPluginHost* base,
                                                                          const gchar* message);
static void spit_data_imports_welcome_data_imports_host_real_install_dialog_pane (SpitDataImportsPluginHost* base,
                                                                           SpitDataImportsDialogPane* pane,
                                                                           SpitDataImportsPluginHostButtonMode button_mode);
static void spit_data_imports_welcome_data_imports_host_real_install_static_message_pane (SpitDataImportsPluginHost* base,
                                                                                   const gchar* message,
                                                                                   SpitDataImportsPluginHostButtonMode button_mode);
static void spit_data_imports_welcome_data_imports_host_real_install_library_selection_pane (SpitDataImportsPluginHost* base,
                                                                                      const gchar* welcome_message,
                                                                                      SpitDataImportsImportableLibrary** discovered_libraries,
                                                                                      int discovered_libraries_length1,
                                                                                      const gchar* file_select_label);
GType welcome_service_entry_get_type (void) G_GNUC_CONST;
void spit_data_imports_welcome_import_meta_host_install_service_entry (SpitDataImportsWelcomeImportMetaHost* self,
                                                                       WelcomeServiceEntry* entry);
SpitDataImportsWelcomeImportServiceEntry* spit_data_imports_welcome_import_service_entry_new (SpitDataImportsPluginHost* host,
                                                                                              const gchar* pluggable_name,
                                                                                              SpitDataImportsImportableLibrary** discovered_libraries,
                                                                                              int discovered_libraries_length1);
SpitDataImportsWelcomeImportServiceEntry* spit_data_imports_welcome_import_service_entry_construct (GType object_type,
                                                                                                    SpitDataImportsPluginHost* host,
                                                                                                    const gchar* pluggable_name,
                                                                                                    SpitDataImportsImportableLibrary** discovered_libraries,
                                                                                                    int discovered_libraries_length1);
GType spit_data_imports_welcome_import_service_entry_get_type (void) G_GNUC_CONST;
static void spit_data_imports_welcome_data_imports_host_real_install_import_progress_pane (SpitDataImportsPluginHost* base,
                                                                                    const gchar* message);
static void spit_data_imports_welcome_data_imports_host_real_update_import_progress_pane (SpitDataImportsPluginHost* base,
                                                                                   gdouble progress,
                                                                                   const gchar* progress_message);
static void spit_data_imports_welcome_data_imports_host_real_prepare_media_items_for_import (SpitDataImportsPluginHost* base,
                                                                                      SpitDataImportsImportableMediaItem** items,
                                                                                      int items_length1,
                                                                                      gdouble progress,
                                                                                      gdouble host_progress_delta,
                                                                                      const gchar* progress_message);
static void spit_data_imports_welcome_data_imports_host_real_finalize_import (SpitDataImportsPluginHost* base,
                                                                       SpitDataImportsImportedItemsCountCallback report_imported_items_count,
                                                                       void* report_imported_items_count_target,
                                                                       const gchar* finalize_message);
void spit_data_imports_welcome_import_meta_host_finalize_import (SpitDataImportsWelcomeImportMetaHost* self,
                                                                 SpitDataImportsWelcomeDataImportsHost* host);
static void spit_data_imports_welcome_data_imports_host_finalize (GObject * obj);
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntryPrivate))
static SpitDataImportsImportableLibrary** _vala_array_dup21 (SpitDataImportsImportableLibrary** self,
                                                      int length);
static gchar* spit_data_imports_welcome_import_service_entry_real_get_service_name (WelcomeServiceEntry* base);
static void spit_data_imports_welcome_import_service_entry_real_execute (WelcomeServiceEntry* base);
static void spit_data_imports_welcome_import_service_entry_finalize (GObject * obj);
GType welcome_dialog_get_type (void) G_GNUC_CONST;
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostPrivate))
SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_new (WelcomeDialog* dialog);
SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_construct (GType object_type,
                                                                                            WelcomeDialog* dialog);
void spit_data_imports_welcome_import_meta_host_start (SpitDataImportsWelcomeImportMetaHost* self);
SpitDataImportsService** spit_data_imports_load_all_services (int* result_length1);
gchar* welcome_service_entry_get_service_name (WelcomeServiceEntry* self);
void welcome_dialog_install_service_entry (WelcomeDialog* self,
                                           WelcomeServiceEntry* entry);
static void spit_data_imports_welcome_import_meta_host_finalize (GObject * obj);
SpitDataImportsService** spit_data_imports_load_services (gboolean load_all,
                                                          int* result_length1);
GeeCollection* plugins_get_pluggables_for_type (GType type,
                                                GCompareDataFunc compare_func,
                                                void* compare_func_target,
                                                GDestroyNotify compare_func_target_destroy_notify,
                                                gboolean include_disabled);
gchar* plugins_get_pluggable_module_id (SpitPluggable* needle);
static void _vala_array_add71 (SpitDataImportsService** * array,
                        int* length,
                        int* size,
                        SpitDataImportsService* value);
static gint __lambda25_ (void* a,
                  void* b);
gint utf8_cs_compare (void* a,
                      void* b);
static gint ___lambda25____compar_fn_t (void* key1,
                                 void* key2);
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
gpointer batch_import_result_ref (gpointer instance);
void batch_import_result_unref (gpointer instance);
GParamSpec* param_spec_batch_import_result (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
void value_set_batch_import_result (GValue* value,
                                    gpointer v_object);
void value_take_batch_import_result (GValue* value,
                                     gpointer v_object);
gpointer value_get_batch_import_result (const GValue* value);
GType batch_import_result_get_type (void) G_GNUC_CONST;
ImportManifest* import_manifest_new (GeeList* prefailed,
                                     GeeList* pre_already_imported);
ImportManifest* import_manifest_construct (GType object_type,
                                           GeeList* prefailed,
                                           GeeList* pre_already_imported);
void import_manifest_add_result (ImportManifest* self,
                                 BatchImportResult* batch_result);
void data_imports_ui_data_imports_dialog_terminate_instance (void);
gpointer import_ui_question_params_ref (gpointer instance);
void import_ui_question_params_unref (gpointer instance);
GParamSpec* import_ui_param_spec_question_params (const gchar* name,
                                                  const gchar* nick,
                                                  const gchar* blurb,
                                                  GType object_type,
                                                  GParamFlags flags);
void import_ui_value_set_question_params (GValue* value,
                                          gpointer v_object);
void import_ui_value_take_question_params (GValue* value,
                                           gpointer v_object);
gpointer import_ui_value_get_question_params (const GValue* value);
GType import_ui_question_params_get_type (void) G_GNUC_CONST;
gboolean import_ui_report_manifest (ImportManifest* manifest,
                                    gboolean show_dest_id,
                                    ImportUIQuestionParams* question);
time_t spit_data_imports_data_import_job_get_exposure_time (SpitDataImportsDataImportJob* self);
static void _vala_array_destroy (gpointer array,
                          gint array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gint array_length,
                       GDestroyNotify destroy_func);


SpitDataImportsCoreImporter*
spit_data_imports_core_importer_construct (GType object_type,
                                           SpitDataImportsPluginHost* host)
{
	SpitDataImportsCoreImporter* self = NULL;
#line 14 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_PLUGIN_HOST (host), NULL);
#line 14 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsCoreImporter*) g_type_create_instance (object_type);
#line 15 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->host = host;
#line 14 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 862 "DataImportsPluginHost.c"
}


SpitDataImportsCoreImporter*
spit_data_imports_core_importer_new (SpitDataImportsPluginHost* host)
{
#line 14 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_core_importer_construct (SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, host);
#line 871 "DataImportsPluginHost.c"
}


static gint64
_spit_data_imports_import_job_comparator_comparator (void* a,
                                                     void* b,
                                                     gpointer self)
{
	gint64 result;
	result = spit_data_imports_import_job_comparator (a, b);
#line 26 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 884 "DataImportsPluginHost.c"
}


static gpointer
_g_object_ref0 (gpointer self)
{
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self ? g_object_ref (self) : NULL;
#line 893 "DataImportsPluginHost.c"
}


static void
_spit_data_imports_data_import_reporter_batch_import_import_reporter (ImportManifest* manifest,
                                                                      BatchImportRoll* import_roll,
                                                                      gpointer self)
{
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_import_reporter (manifest, import_roll);
#line 904 "DataImportsPluginHost.c"
}


void
spit_data_imports_core_importer_prepare_media_items_for_import (SpitDataImportsCoreImporter* self,
                                                                SpitDataImportsImportableMediaItem** items,
                                                                int items_length1,
                                                                gdouble progress,
                                                                gdouble host_progress_delta,
                                                                const gchar* progress_message)
{
	SpitDataImportsPluginHost* _tmp0_;
	SortedList* jobs = NULL;
	SortedList* _tmp1_;
	GeeArrayList* already_imported = NULL;
	GeeArrayList* _tmp2_;
	GeeArrayList* failed = NULL;
	GeeArrayList* _tmp3_;
	gint item_idx = 0;
	gdouble item_progress_delta = 0.0;
	SortedList* _tmp31_;
	gint _tmp32_;
	gint _tmp33_;
	SpitDataImportsPluginHost* _tmp57_;
#line 18 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_CORE_IMPORTER (self));
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->host;
#line 24 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_update_import_progress_pane (_tmp0_, progress, progress_message);
#line 26 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = sorted_list_new (SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, (GDestroyNotify) batch_import_job_unref, _spit_data_imports_import_job_comparator_comparator, NULL);
#line 26 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	jobs = _tmp1_;
#line 28 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = gee_array_list_new (SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, (GDestroyNotify) batch_import_job_unref, NULL, NULL, NULL);
#line 28 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	already_imported = _tmp2_;
#line 30 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = gee_array_list_new (SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, (GDestroyNotify) batch_import_job_unref, NULL, NULL, NULL);
#line 30 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	failed = _tmp3_;
#line 33 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	item_idx = 0;
#line 34 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	item_progress_delta = host_progress_delta / items_length1;
#line 951 "DataImportsPluginHost.c"
	{
		SpitDataImportsImportableMediaItem** src_item_collection = NULL;
		gint src_item_collection_length1 = 0;
		gint _src_item_collection_size_ = 0;
		gint src_item_it = 0;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		src_item_collection = items;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		src_item_collection_length1 = items_length1;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		for (src_item_it = 0; src_item_it < items_length1; src_item_it = src_item_it + 1) {
#line 963 "DataImportsPluginHost.c"
			SpitDataImportsImportableMediaItem* _tmp4_;
			SpitDataImportsImportableMediaItem* src_item = NULL;
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp4_ = _g_object_ref0 (src_item_collection[src_item_it]);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			src_item = _tmp4_;
#line 970 "DataImportsPluginHost.c"
			{
				SpitDataImportsDataImportSource* import_source = NULL;
				SpitDataImportsImportableMediaItem* _tmp5_;
				SpitDataImportsDataImportSource* _tmp6_;
				SpitDataImportsDataImportSource* _tmp7_;
				SpitDataImportsDataImportSource* _tmp15_;
				SortedList* _tmp23_;
				SpitDataImportsDataImportSource* _tmp24_;
				SpitDataImportsDataImportJob* _tmp25_;
				SpitDataImportsDataImportJob* _tmp26_;
				gint _tmp27_;
				SpitDataImportsPluginHost* _tmp28_;
				gint _tmp29_;
				gdouble _tmp30_;
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp5_ = src_item;
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp6_ = spit_data_imports_data_import_source_new (_tmp5_);
#line 36 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				import_source = _tmp6_;
#line 38 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp7_ = import_source;
#line 38 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				if (!spit_data_imports_data_import_source_was_backing_file_found (_tmp7_)) {
#line 995 "DataImportsPluginHost.c"
					SpitDataImportsDataImportSource* _tmp8_;
					gchar* _tmp9_;
					gchar* _tmp10_;
					GeeArrayList* _tmp11_;
					SpitDataImportsDataImportSource* _tmp12_;
					SpitDataImportsDataImportJob* _tmp13_;
					SpitDataImportsDataImportJob* _tmp14_;
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp8_ = import_source;
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp9_ = spit_data_imports_data_import_source_get_filename (_tmp8_);
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp10_ = _tmp9_;
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					g_message ("DataImportsPluginHost.vala:39: Skipping import of %s: backing file not" \
" found", _tmp10_);
#line 39 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_g_free0 (_tmp10_);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp11_ = failed;
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp12_ = import_source;
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp13_ = spit_data_imports_data_import_job_new (_tmp12_);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp14_ = _tmp13_;
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp14_);
#line 41 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_batch_import_job_unref0 (_tmp14_);
#line 43 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_spit_data_imports_data_import_source_unref0 (import_source);
#line 43 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_g_object_unref0 (src_item);
#line 43 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					continue;
#line 1031 "DataImportsPluginHost.c"
				}
#line 46 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp15_ = import_source;
#line 46 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				if (spit_data_imports_data_import_source_is_already_imported (_tmp15_)) {
#line 1037 "DataImportsPluginHost.c"
					SpitDataImportsDataImportSource* _tmp16_;
					gchar* _tmp17_;
					gchar* _tmp18_;
					GeeArrayList* _tmp19_;
					SpitDataImportsDataImportSource* _tmp20_;
					SpitDataImportsDataImportJob* _tmp21_;
					SpitDataImportsDataImportJob* _tmp22_;
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp16_ = import_source;
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp17_ = spit_data_imports_data_import_source_get_filename (_tmp16_);
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp18_ = _tmp17_;
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					g_message ("DataImportsPluginHost.vala:47: Skipping import of %s: checksum detecte" \
"d in library", _tmp18_);
#line 47 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_g_free0 (_tmp18_);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp19_ = already_imported;
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp20_ = import_source;
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp21_ = spit_data_imports_data_import_job_new (_tmp20_);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_tmp22_ = _tmp21_;
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp22_);
#line 49 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_batch_import_job_unref0 (_tmp22_);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_spit_data_imports_data_import_source_unref0 (import_source);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					_g_object_unref0 (src_item);
#line 51 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					continue;
#line 1073 "DataImportsPluginHost.c"
				}
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp23_ = jobs;
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp24_ = import_source;
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp25_ = spit_data_imports_data_import_job_new (_tmp24_);
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp26_ = _tmp25_;
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_COLLECTION, GeeCollection), _tmp26_);
#line 54 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_batch_import_job_unref0 (_tmp26_);
#line 55 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp27_ = item_idx;
#line 55 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				item_idx = _tmp27_ + 1;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp28_ = self->priv->host;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp29_ = item_idx;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp30_ = item_progress_delta;
#line 56 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				spit_data_imports_plugin_host_update_import_progress_pane (_tmp28_, progress + (_tmp29_ * _tmp30_), NULL);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_spit_data_imports_data_import_source_unref0 (import_source);
#line 35 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (src_item);
#line 1103 "DataImportsPluginHost.c"
			}
		}
	}
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp31_ = jobs;
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp32_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, GEE_TYPE_COLLECTION, GeeCollection));
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp33_ = _tmp32_;
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp33_ > 0) {
#line 1115 "DataImportsPluginHost.c"
		BatchImportRoll* _tmp34_;
		gchar* db_name = NULL;
		SpitDataImportsPluginHost* _tmp36_;
		SpitDataImportsDataImporter* _tmp37_;
		SpitDataImportsDataImporter* _tmp38_;
		SpitDataImportsService* _tmp39_;
		SpitDataImportsService* _tmp40_;
		const gchar* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
		BatchImport* batch_import = NULL;
		SortedList* _tmp44_;
		const gchar* _tmp45_;
		GeeArrayList* _tmp46_;
		GeeArrayList* _tmp47_;
		BatchImportRoll* _tmp48_;
		BatchImport* _tmp49_;
		LibraryWindow* _tmp50_;
		LibraryWindow* _tmp51_;
		BatchImport* _tmp52_;
		gint _tmp53_;
		SortedList* _tmp54_;
		gint _tmp55_;
		gint _tmp56_;
#line 63 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp34_ = self->current_import_roll;
#line 63 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		if (_tmp34_ == NULL) {
#line 1144 "DataImportsPluginHost.c"
			BatchImportRoll* _tmp35_;
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp35_ = batch_import_roll_new ();
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_batch_import_roll_unref0 (self->current_import_roll);
#line 64 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			self->current_import_roll = _tmp35_;
#line 1152 "DataImportsPluginHost.c"
		}
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp36_ = self->priv->host;
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp37_ = spit_data_imports_plugin_host_get_data_importer (_tmp36_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp38_ = _tmp37_;
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp39_ = spit_data_imports_data_importer_get_service (_tmp38_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp40_ = _tmp39_;
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp41_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp42_ = g_strdup_printf (_ ("%s Database"), _tmp41_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp43_ = _tmp42_;
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp40_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp38_);
#line 65 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		db_name = _tmp43_;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp44_ = jobs;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp45_ = db_name;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp46_ = failed;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp47_ = already_imported;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp48_ = self->current_import_roll;
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp49_ = batch_import_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp44_, GEE_TYPE_ITERABLE, GeeIterable), _tmp45_, _spit_data_imports_data_import_reporter_batch_import_import_reporter, NULL, _tmp46_, _tmp47_, NULL, _tmp48_, NULL);
#line 66 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		batch_import = _tmp49_;
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp50_ = library_window_get_app ();
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp51_ = _tmp50_;
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp52_ = batch_import;
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		library_window_enqueue_batch_import (_tmp51_, _tmp52_, TRUE);
#line 69 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp51_);
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp53_ = self->imported_items_count;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp54_ = jobs;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp55_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, GEE_TYPE_COLLECTION, GeeCollection));
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp56_ = _tmp55_;
#line 70 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		self->imported_items_count = _tmp53_ + _tmp56_;
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (batch_import);
#line 59 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_free0 (db_name);
#line 1214 "DataImportsPluginHost.c"
	}
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp57_ = self->priv->host;
#line 73 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_update_import_progress_pane (_tmp57_, progress + host_progress_delta, NULL);
#line 18 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (failed);
#line 18 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (already_imported);
#line 18 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (jobs);
#line 1226 "DataImportsPluginHost.c"
}


void
spit_data_imports_core_importer_finalize_import (SpitDataImportsCoreImporter* self)
{
	gchar* db_name = NULL;
	SpitDataImportsPluginHost* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
	SpitDataImportsDataImporter* _tmp2_;
	SpitDataImportsService* _tmp3_;
	SpitDataImportsService* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	BatchImport* batch_import = NULL;
	GeeArrayList* _tmp8_;
	GeeArrayList* _tmp9_;
	BatchImportRoll* _tmp10_;
	BatchImport* _tmp11_;
	BatchImport* _tmp12_;
	LibraryWindow* _tmp13_;
	LibraryWindow* _tmp14_;
#line 76 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_CORE_IMPORTER (self));
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->host;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_plugin_host_get_data_importer (_tmp0_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_data_imports_data_importer_get_service (_tmp2_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = _tmp3_;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = g_strdup_printf (_ ("%s Database"), _tmp5_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = _tmp6_;
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp4_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp2_);
#line 78 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	db_name = _tmp7_;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp8_ = gee_array_list_new (TYPE_BATCH_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, (GDestroyNotify) batch_import_job_unref, NULL, NULL, NULL);
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp9_ = _tmp8_;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp10_ = self->current_import_roll;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp11_ = batch_import_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ITERABLE, GeeIterable), db_name, _spit_data_imports_data_import_reporter_batch_import_import_reporter, NULL, NULL, NULL, NULL, _tmp10_, NULL);
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp12_ = _tmp11_;
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp9_);
#line 79 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	batch_import = _tmp12_;
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp13_ = library_window_get_app ();
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp14_ = _tmp13_;
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	library_window_enqueue_batch_import (_tmp14_, batch_import, TRUE);
#line 82 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp14_);
#line 83 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_batch_import_roll_unref0 (self->current_import_roll);
#line 83 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->current_import_roll = NULL;
#line 76 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (batch_import);
#line 76 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (db_name);
#line 1304 "DataImportsPluginHost.c"
}


static void
spit_data_imports_value_core_importer_init (GValue* value)
{
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	value->data[0].v_pointer = NULL;
#line 1313 "DataImportsPluginHost.c"
}


static void
spit_data_imports_value_core_importer_free_value (GValue* value)
{
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_core_importer_unref (value->data[0].v_pointer);
#line 1324 "DataImportsPluginHost.c"
	}
}


static void
spit_data_imports_value_core_importer_copy_value (const GValue* src_value,
                                                  GValue* dest_value)
{
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (src_value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		dest_value->data[0].v_pointer = spit_data_imports_core_importer_ref (src_value->data[0].v_pointer);
#line 1337 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1341 "DataImportsPluginHost.c"
	}
}


static gpointer
spit_data_imports_value_core_importer_peek_pointer (const GValue* value)
{
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return value->data[0].v_pointer;
#line 1351 "DataImportsPluginHost.c"
}


static gchar*
spit_data_imports_value_core_importer_collect_value (GValue* value,
                                                     guint n_collect_values,
                                                     GTypeCValue* collect_values,
                                                     guint collect_flags)
{
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (collect_values[0].v_pointer) {
#line 1363 "DataImportsPluginHost.c"
		SpitDataImportsCoreImporter * object;
		object = collect_values[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		if (object->parent_instance.g_class == NULL) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1370 "DataImportsPluginHost.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1374 "DataImportsPluginHost.c"
		}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = spit_data_imports_core_importer_ref (object);
#line 1378 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = NULL;
#line 1382 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return NULL;
#line 1386 "DataImportsPluginHost.c"
}


static gchar*
spit_data_imports_value_core_importer_lcopy_value (const GValue* value,
                                                   guint n_collect_values,
                                                   GTypeCValue* collect_values,
                                                   guint collect_flags)
{
	SpitDataImportsCoreImporter ** object_p;
	object_p = collect_values[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (!object_p) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1402 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (!value->data[0].v_pointer) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*object_p = NULL;
#line 1408 "DataImportsPluginHost.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*object_p = value->data[0].v_pointer;
#line 1412 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*object_p = spit_data_imports_core_importer_ref (value->data[0].v_pointer);
#line 1416 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return NULL;
#line 1420 "DataImportsPluginHost.c"
}


GParamSpec*
spit_data_imports_param_spec_core_importer (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags)
{
	SpitDataImportsParamSpecCoreImporter* spec;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (g_type_is_a (object_type, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER), NULL);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return G_PARAM_SPEC (spec);
#line 1440 "DataImportsPluginHost.c"
}


gpointer
spit_data_imports_value_get_core_importer (const GValue* value)
{
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER), NULL);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return value->data[0].v_pointer;
#line 1451 "DataImportsPluginHost.c"
}


void
spit_data_imports_value_set_core_importer (GValue* value,
                                           gpointer v_object)
{
	SpitDataImportsCoreImporter * old;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	old = value->data[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (v_object) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = v_object;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_core_importer_ref (value->data[0].v_pointer);
#line 1474 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = NULL;
#line 1478 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (old) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_core_importer_unref (old);
#line 1484 "DataImportsPluginHost.c"
	}
}


void
spit_data_imports_value_take_core_importer (GValue* value,
                                            gpointer v_object)
{
	SpitDataImportsCoreImporter * old;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	old = value->data[0].v_pointer;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (v_object) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = v_object;
#line 1506 "DataImportsPluginHost.c"
	} else {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		value->data[0].v_pointer = NULL;
#line 1510 "DataImportsPluginHost.c"
	}
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (old) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_core_importer_unref (old);
#line 1516 "DataImportsPluginHost.c"
	}
}


static void
spit_data_imports_core_importer_class_init (SpitDataImportsCoreImporterClass * klass)
{
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	((SpitDataImportsCoreImporterClass *) klass)->finalize = spit_data_imports_core_importer_finalize;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsCoreImporterPrivate));
#line 1530 "DataImportsPluginHost.c"
}


static void
spit_data_imports_core_importer_instance_init (SpitDataImportsCoreImporter * self)
{
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_CORE_IMPORTER_GET_PRIVATE (self);
#line 11 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->imported_items_count = 0;
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->current_import_roll = NULL;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->ref_count = 1;
#line 1545 "DataImportsPluginHost.c"
}


static void
spit_data_imports_core_importer_finalize (SpitDataImportsCoreImporter * obj)
{
	SpitDataImportsCoreImporter * self;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_CORE_IMPORTER, SpitDataImportsCoreImporter);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_signal_handlers_destroy (self);
#line 12 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_batch_import_roll_unref0 (self->current_import_roll);
#line 1559 "DataImportsPluginHost.c"
}


GType
spit_data_imports_core_importer_get_type (void)
{
	static volatile gsize spit_data_imports_core_importer_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_core_importer_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { spit_data_imports_value_core_importer_init, spit_data_imports_value_core_importer_free_value, spit_data_imports_value_core_importer_copy_value, spit_data_imports_value_core_importer_peek_pointer, "p", spit_data_imports_value_core_importer_collect_value, "p", spit_data_imports_value_core_importer_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsCoreImporterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_core_importer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsCoreImporter), 0, (GInstanceInitFunc) spit_data_imports_core_importer_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType spit_data_imports_core_importer_type_id;
		spit_data_imports_core_importer_type_id = g_type_register_fundamental (g_type_fundamental_next (), "SpitDataImportsCoreImporter", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&spit_data_imports_core_importer_type_id__volatile, spit_data_imports_core_importer_type_id);
	}
	return spit_data_imports_core_importer_type_id__volatile;
}


gpointer
spit_data_imports_core_importer_ref (gpointer instance)
{
	SpitDataImportsCoreImporter * self;
	self = instance;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_atomic_int_inc (&self->ref_count);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return instance;
#line 1588 "DataImportsPluginHost.c"
}


void
spit_data_imports_core_importer_unref (gpointer instance)
{
	SpitDataImportsCoreImporter * self;
	self = instance;
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		SPIT_DATA_IMPORTS_CORE_IMPORTER_GET_CLASS (self)->finalize (self);
#line 9 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1603 "DataImportsPluginHost.c"
	}
}


SpitDataImportsConcreteDataImportsHost*
spit_data_imports_concrete_data_imports_host_construct (GType object_type,
                                                        SpitDataImportsService* service,
                                                        DataImportsUIDataImportsDialog* dialog)
{
	SpitDataImportsConcreteDataImportsHost * self = NULL;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsCoreImporter* _tmp1_;
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_SERVICE (service), NULL);
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (DATA_IMPORTS_UI_IS_DATA_IMPORTS_DIALOG (dialog), NULL);
#line 97 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsConcreteDataImportsHost*) plugins_standard_host_interface_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (service, SPIT_TYPE_PLUGGABLE, SpitPluggable), "data_imports");
#line 98 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->dialog = dialog;
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_service_create_data_importer (service, G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->active_importer);
#line 100 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->active_importer = _tmp0_;
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_core_importer_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_spit_data_imports_core_importer_unref0 (self->priv->core_importer);
#line 101 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->core_importer = _tmp1_;
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 1638 "DataImportsPluginHost.c"
}


SpitDataImportsConcreteDataImportsHost*
spit_data_imports_concrete_data_imports_host_new (SpitDataImportsService* service,
                                                  DataImportsUIDataImportsDialog* dialog)
{
#line 96 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_concrete_data_imports_host_construct (SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, service, dialog);
#line 1648 "DataImportsPluginHost.c"
}


static SpitDataImportsDataImporter*
spit_data_imports_concrete_data_imports_host_real_get_data_importer (SpitDataImportsPluginHost* base)
{
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsDataImporter* result = NULL;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
#line 104 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->active_importer;
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp1_;
#line 105 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 1669 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_start_importing (SpitDataImportsPluginHost* base)
{
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
	gboolean _tmp2_;
	SpitDataImportsDataImporter* _tmp3_;
	SpitDataImportsDataImporter* _tmp4_;
#line 108 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_is_running (_tmp1_);
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 109 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp2_) {
#line 110 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		return;
#line 1696 "DataImportsPluginHost.c"
	}
#line 112 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:112: ConcreteDataImportsHost.start_importin" \
"g( ): invoked.");
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = _tmp3_;
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_importer_start (_tmp4_);
#line 114 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp4_);
#line 1708 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_stop_importing (SpitDataImportsPluginHost* base)
{
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
	gboolean _tmp2_;
#line 117 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 118 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:118: ConcreteDataImportsHost.stop_importing" \
"( ): invoked.");
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_is_running (_tmp1_);
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 120 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp2_) {
#line 1733 "DataImportsPluginHost.c"
		SpitDataImportsDataImporter* _tmp3_;
		SpitDataImportsDataImporter* _tmp4_;
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp3_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp4_ = _tmp3_;
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_data_importer_stop (_tmp4_);
#line 121 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp4_);
#line 1744 "DataImportsPluginHost.c"
	}
#line 123 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_clean_up (self);
#line 125 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->importing_halted = TRUE;
#line 1750 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_clean_up (SpitDataImportsConcreteDataImportsHost* self)
{
#line 128 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST (self));
#line 129 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->progress_pane);
#line 129 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->progress_pane = NULL;
#line 1763 "DataImportsPluginHost.c"
}


void
spit_data_imports_concrete_data_imports_host_set_button_mode (SpitDataImportsConcreteDataImportsHost* self,
                                                              SpitDataImportsPluginHostButtonMode mode)
{
#line 132 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_CONCRETE_DATA_IMPORTS_HOST (self));
#line 133 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (mode == SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CLOSE) {
#line 1775 "DataImportsPluginHost.c"
		DataImportsUIDataImportsDialog* _tmp0_;
#line 134 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = self->priv->dialog;
#line 134 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		data_imports_ui_data_imports_dialog_set_close_button_mode (_tmp0_);
#line 1781 "DataImportsPluginHost.c"
	} else {
#line 135 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		if (mode == SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CANCEL) {
#line 1785 "DataImportsPluginHost.c"
			DataImportsUIDataImportsDialog* _tmp1_;
#line 136 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp1_ = self->priv->dialog;
#line 136 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			data_imports_ui_data_imports_dialog_set_cancel_button_mode (_tmp1_);
#line 1791 "DataImportsPluginHost.c"
		} else {
#line 138 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			g_error ("DataImportsPluginHost.vala:138: unrecognized button mode enumeration v" \
"alue");
#line 1795 "DataImportsPluginHost.c"
		}
	}
}


static void
spit_data_imports_concrete_data_imports_host_real_post_error (SpitDataImportsPluginHost* base,
                                                              GError* err)
{
	SpitDataImportsConcreteDataImportsHost * self;
	const gchar* _tmp0_;
#line 143 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 144 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = err->message;
#line 144 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_post_error_message (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), _tmp0_);
#line 1813 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_post_error_message (SpitDataImportsPluginHost* base,
                                                                      const gchar* message)
{
	SpitDataImportsConcreteDataImportsHost * self;
	gchar* msg = NULL;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsService* _tmp1_;
	SpitDataImportsService* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	DataImportsUIDataImportsDialog* _tmp12_;
	const gchar* _tmp13_;
	DataImportsUIStaticMessagePane* _tmp14_;
	DataImportsUIStaticMessagePane* _tmp15_;
	DataImportsUIDataImportsDialog* _tmp16_;
	DataImportsUIDataImportsDialog* _tmp17_;
	SpitDataImportsDataImporter* _tmp18_;
	SpitDataImportsDataImporter* _tmp19_;
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->active_importer;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_data_importer_get_service (_tmp0_);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = g_strdup_printf (_ ("Importing from %s can’t continue because an error occurred:"), _tmp3_);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = _tmp4_;
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp2_);
#line 148 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	msg = _tmp5_;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = msg;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = g_markup_printf_escaped ("\n\n<i>%s</i>\n\n", message);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp8_ = _tmp7_;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp9_ = g_strconcat (_tmp6_, _tmp8_, NULL);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (msg);
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	msg = _tmp9_;
#line 150 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (_tmp8_);
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp10_ = msg;
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp11_ = g_strconcat (_tmp10_, _ ("To try importing from another service, select one from the above menu."), NULL);
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (msg);
#line 151 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	msg = _tmp11_;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp12_ = self->priv->dialog;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp13_ = msg;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp14_ = data_imports_ui_static_message_pane_new_with_pango (_tmp13_);
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp15_ = _tmp14_;
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_install_pane (_tmp12_, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 153 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp15_);
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp16_ = self->priv->dialog;
#line 154 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_set_close_button_mode (_tmp16_);
#line 155 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp17_ = self->priv->dialog;
#line 155 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_unlock_service (_tmp17_);
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp18_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp19_ = _tmp18_;
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_importer_stop (_tmp19_);
#line 157 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp19_);
#line 162 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_clean_up (self);
#line 147 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (msg);
#line 1917 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_install_dialog_pane (SpitDataImportsPluginHost* base,
                                                                       SpitDataImportsDialogPane* pane,
                                                                       SpitDataImportsPluginHostButtonMode button_mode)
{
	SpitDataImportsConcreteDataImportsHost * self;
	gboolean _tmp0_ = FALSE;
	SpitDataImportsDataImporter* _tmp1_;
	SpitDataImportsDataImporter* _tmp2_;
	gboolean _tmp3_;
	DataImportsUIDataImportsDialog* _tmp6_;
#line 165 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 165 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_DIALOG_PANE (pane));
#line 167 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:167: DataImports.PluginHost: install_dialog" \
"_pane( ): invoked.");
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_ == NULL;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp2_);
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp3_) {
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = TRUE;
#line 1950 "DataImportsPluginHost.c"
	} else {
		SpitDataImportsDataImporter* _tmp4_;
		SpitDataImportsDataImporter* _tmp5_;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp4_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp5_ = _tmp4_;
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = !spit_data_imports_data_importer_is_running (_tmp5_);
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp5_);
#line 1962 "DataImportsPluginHost.c"
	}
#line 169 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp0_) {
#line 170 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		return;
#line 1968 "DataImportsPluginHost.c"
	}
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = self->priv->dialog;
#line 172 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_install_pane (_tmp6_, pane);
#line 174 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, button_mode);
#line 1976 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_install_static_message_pane (SpitDataImportsPluginHost* base,
                                                                               const gchar* message,
                                                                               SpitDataImportsPluginHostButtonMode button_mode)
{
	SpitDataImportsConcreteDataImportsHost * self;
	DataImportsUIDataImportsDialog* _tmp0_;
	DataImportsUIStaticMessagePane* _tmp1_;
	DataImportsUIStaticMessagePane* _tmp2_;
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 177 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 180 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, button_mode);
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->dialog;
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = data_imports_ui_static_message_pane_new_with_pango (message);
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_install_pane (_tmp0_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 182 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp2_);
#line 2005 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_install_library_selection_pane (SpitDataImportsPluginHost* base,
                                                                                  const gchar* welcome_message,
                                                                                  SpitDataImportsImportableLibrary** discovered_libraries,
                                                                                  int discovered_libraries_length1,
                                                                                  const gchar* file_select_label)
{
	SpitDataImportsConcreteDataImportsHost * self;
	gboolean _tmp0_ = FALSE;
#line 185 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 185 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (welcome_message != NULL);
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (discovered_libraries_length1 == 0) {
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = file_select_label == NULL;
#line 2026 "DataImportsPluginHost.c"
	} else {
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = FALSE;
#line 2030 "DataImportsPluginHost.c"
	}
#line 190 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp0_) {
#line 191 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_plugin_host_post_error_message (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), "Libraries or file option needed");
#line 2036 "DataImportsPluginHost.c"
	} else {
		DataImportsUIDataImportsDialog* _tmp1_;
		DataImportsUILibrarySelectionPane* _tmp2_;
		DataImportsUILibrarySelectionPane* _tmp3_;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp1_ = self->priv->dialog;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp2_ = data_imports_ui_library_selection_pane_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), welcome_message, discovered_libraries, discovered_libraries_length1, file_select_label);
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp3_ = _tmp2_;
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		data_imports_ui_data_imports_dialog_install_pane (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 193 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp3_);
#line 2051 "DataImportsPluginHost.c"
	}
#line 199 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 2055 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_install_import_progress_pane (SpitDataImportsPluginHost* base,
                                                                                const gchar* message)
{
	SpitDataImportsConcreteDataImportsHost * self;
	DataImportsUIProgressPane* _tmp0_;
	DataImportsUIDataImportsDialog* _tmp1_;
	DataImportsUIProgressPane* _tmp2_;
	SpitDataImportsCoreImporter* _tmp3_;
	SpitDataImportsCoreImporter* _tmp4_;
#line 202 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 202 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = data_imports_ui_progress_pane_new (message);
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->progress_pane);
#line 205 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->progress_pane = _tmp0_;
#line 206 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = self->priv->dialog;
#line 206 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = self->priv->progress_pane;
#line 206 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	data_imports_ui_data_imports_dialog_install_pane (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_DATA_IMPORTS_TYPE_DIALOG_PANE, SpitDataImportsDialogPane));
#line 207 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 209 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = self->priv->core_importer;
#line 209 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_->imported_items_count = 0;
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = self->priv->core_importer;
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_batch_import_roll_unref0 (_tmp4_->current_import_roll);
#line 210 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_->current_import_roll = NULL;
#line 2097 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_update_import_progress_pane (SpitDataImportsPluginHost* base,
                                                                               gdouble progress,
                                                                               const gchar* progress_message)
{
	SpitDataImportsConcreteDataImportsHost * self;
	DataImportsUIProgressPane* _tmp0_;
#line 213 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 217 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->progress_pane;
#line 217 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp0_ != NULL) {
#line 2114 "DataImportsPluginHost.c"
		DataImportsUIProgressPane* _tmp1_;
#line 218 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp1_ = self->priv->progress_pane;
#line 218 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		data_imports_ui_progress_pane_update_progress (_tmp1_, progress, progress_message);
#line 2120 "DataImportsPluginHost.c"
	}
}


static void
spit_data_imports_concrete_data_imports_host_real_prepare_media_items_for_import (SpitDataImportsPluginHost* base,
                                                                                  SpitDataImportsImportableMediaItem** items,
                                                                                  int items_length1,
                                                                                  gdouble progress,
                                                                                  gdouble host_progress_delta,
                                                                                  const gchar* progress_message)
{
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsCoreImporter* _tmp0_;
#line 222 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->core_importer;
#line 228 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_prepare_media_items_for_import (_tmp0_, items, items_length1, progress, host_progress_delta, progress_message);
#line 2141 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_real_finalize_import (SpitDataImportsPluginHost* base,
                                                                   SpitDataImportsImportedItemsCountCallback report_imported_items_count,
                                                                   void* report_imported_items_count_target,
                                                                   const gchar* finalize_message)
{
	SpitDataImportsConcreteDataImportsHost * self;
	SpitDataImportsCoreImporter* _tmp0_;
	SpitDataImportsCoreImporter* _tmp1_;
	gint _tmp2_;
	SpitDataImportsCoreImporter* _tmp3_;
	gint _tmp4_;
#line 231 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 235 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_update_import_progress_pane (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), 1.0, finalize_message);
#line 236 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_set_button_mode (self, SPIT_DATA_IMPORTS_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->core_importer;
#line 237 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_finalize_import (_tmp0_);
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = self->priv->core_importer;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_->imported_items_count;
#line 238 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	report_imported_items_count (_tmp2_, report_imported_items_count_target);
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = self->priv->core_importer;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = _tmp3_->imported_items_count;
#line 239 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp4_ > 0) {
#line 2179 "DataImportsPluginHost.c"
		LibraryWindow* _tmp5_;
		LibraryWindow* _tmp6_;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp5_ = library_window_get_app ();
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp6_ = _tmp5_;
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		library_window_switch_to_import_queue_page (_tmp6_);
#line 240 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp6_);
#line 2190 "DataImportsPluginHost.c"
	}
}


static void
spit_data_imports_concrete_data_imports_host_class_init (SpitDataImportsConcreteDataImportsHostClass * klass)
{
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_parent_class = g_type_class_peek_parent (klass);
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsConcreteDataImportsHostPrivate));
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (klass)->finalize = spit_data_imports_concrete_data_imports_host_finalize;
#line 2204 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_spit_data_imports_plugin_host_interface_init (SpitDataImportsPluginHostIface * iface)
{
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_concrete_data_imports_host_spit_data_imports_plugin_host_parent_iface = g_type_interface_peek_parent (iface);
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->get_data_importer = (SpitDataImportsDataImporter* (*) (SpitDataImportsPluginHost *)) spit_data_imports_concrete_data_imports_host_real_get_data_importer;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->start_importing = (void (*) (SpitDataImportsPluginHost *)) spit_data_imports_concrete_data_imports_host_real_start_importing;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->stop_importing = (void (*) (SpitDataImportsPluginHost *)) spit_data_imports_concrete_data_imports_host_real_stop_importing;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->post_error = (void (*) (SpitDataImportsPluginHost *, GError*)) spit_data_imports_concrete_data_imports_host_real_post_error;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->post_error_message = (void (*) (SpitDataImportsPluginHost *, const gchar*)) spit_data_imports_concrete_data_imports_host_real_post_error_message;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_dialog_pane = (void (*) (SpitDataImportsPluginHost *, SpitDataImportsDialogPane*, SpitDataImportsPluginHostButtonMode)) spit_data_imports_concrete_data_imports_host_real_install_dialog_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_static_message_pane = (void (*) (SpitDataImportsPluginHost *, const gchar*, SpitDataImportsPluginHostButtonMode)) spit_data_imports_concrete_data_imports_host_real_install_static_message_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_library_selection_pane = (void (*) (SpitDataImportsPluginHost *, const gchar*, SpitDataImportsImportableLibrary**, int, const gchar*)) spit_data_imports_concrete_data_imports_host_real_install_library_selection_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_import_progress_pane = (void (*) (SpitDataImportsPluginHost *, const gchar*)) spit_data_imports_concrete_data_imports_host_real_install_import_progress_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->update_import_progress_pane = (void (*) (SpitDataImportsPluginHost *, gdouble, const gchar*)) spit_data_imports_concrete_data_imports_host_real_update_import_progress_pane;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->prepare_media_items_for_import = (void (*) (SpitDataImportsPluginHost *, SpitDataImportsImportableMediaItem**, int, gdouble, gdouble, const gchar*)) spit_data_imports_concrete_data_imports_host_real_prepare_media_items_for_import;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->finalize_import = (void (*) (SpitDataImportsPluginHost *, SpitDataImportsImportedItemsCountCallback, void*, const gchar*)) spit_data_imports_concrete_data_imports_host_real_finalize_import;
#line 2237 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_instance_init (SpitDataImportsConcreteDataImportsHost * self)
{
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_CONCRETE_DATA_IMPORTS_HOST_GET_PRIVATE (self);
#line 90 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->active_importer = NULL;
#line 91 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->dialog = NULL;
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->progress_pane = NULL;
#line 93 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->importing_halted = FALSE;
#line 2254 "DataImportsPluginHost.c"
}


static void
spit_data_imports_concrete_data_imports_host_finalize (GObject * obj)
{
	SpitDataImportsConcreteDataImportsHost * self;
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_CONCRETE_DATA_IMPORTS_HOST, SpitDataImportsConcreteDataImportsHost);
#line 90 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->active_importer);
#line 92 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->progress_pane);
#line 94 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_spit_data_imports_core_importer_unref0 (self->priv->core_importer);
#line 87 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (spit_data_imports_concrete_data_imports_host_parent_class)->finalize (obj);
#line 2272 "DataImportsPluginHost.c"
}


GType
spit_data_imports_concrete_data_imports_host_get_type (void)
{
	static volatile gsize spit_data_imports_concrete_data_imports_host_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_concrete_data_imports_host_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsConcreteDataImportsHostClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_concrete_data_imports_host_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsConcreteDataImportsHost), 0, (GInstanceInitFunc) spit_data_imports_concrete_data_imports_host_instance_init, NULL };
		static const GInterfaceInfo spit_data_imports_plugin_host_info = { (GInterfaceInitFunc) spit_data_imports_concrete_data_imports_host_spit_data_imports_plugin_host_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType spit_data_imports_concrete_data_imports_host_type_id;
		spit_data_imports_concrete_data_imports_host_type_id = g_type_register_static (PLUGINS_TYPE_STANDARD_HOST_INTERFACE, "SpitDataImportsConcreteDataImportsHost", &g_define_type_info, 0);
		g_type_add_interface_static (spit_data_imports_concrete_data_imports_host_type_id, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, &spit_data_imports_plugin_host_info);
		g_once_init_leave (&spit_data_imports_concrete_data_imports_host_type_id__volatile, spit_data_imports_concrete_data_imports_host_type_id);
	}
	return spit_data_imports_concrete_data_imports_host_type_id__volatile;
}


SpitDataImportsWelcomeDataImportsHost*
spit_data_imports_welcome_data_imports_host_construct (GType object_type,
                                                       SpitDataImportsService* service,
                                                       SpitDataImportsWelcomeImportMetaHost* meta_host)
{
	SpitDataImportsWelcomeDataImportsHost * self = NULL;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsCoreImporter* _tmp1_;
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_SERVICE (service), NULL);
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST (meta_host), NULL);
#line 253 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsWelcomeDataImportsHost*) plugins_standard_host_interface_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (service, SPIT_TYPE_PLUGGABLE, SpitPluggable), "data_imports");
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_service_create_data_importer (service, G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->active_importer);
#line 255 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->active_importer = _tmp0_;
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_core_importer_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_spit_data_imports_core_importer_unref0 (self->priv->core_importer);
#line 256 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->core_importer = _tmp1_;
#line 257 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->meta_host = meta_host;
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 2322 "DataImportsPluginHost.c"
}


SpitDataImportsWelcomeDataImportsHost*
spit_data_imports_welcome_data_imports_host_new (SpitDataImportsService* service,
                                                 SpitDataImportsWelcomeImportMetaHost* meta_host)
{
#line 252 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_welcome_data_imports_host_construct (SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, service, meta_host);
#line 2332 "DataImportsPluginHost.c"
}


static SpitDataImportsDataImporter*
spit_data_imports_welcome_data_imports_host_real_get_data_importer (SpitDataImportsPluginHost* base)
{
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsDataImporter* result = NULL;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
#line 260 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 261 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->active_importer;
#line 261 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 261 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp1_;
#line 261 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 2353 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_start_importing (SpitDataImportsPluginHost* base)
{
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
	gboolean _tmp2_;
	SpitDataImportsDataImporter* _tmp3_;
	SpitDataImportsDataImporter* _tmp4_;
#line 264 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_is_running (_tmp1_);
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 265 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp2_) {
#line 266 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		return;
#line 2380 "DataImportsPluginHost.c"
	}
#line 268 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:268: WelcomeDataImportsHost.start_importing" \
"( ): invoked.");
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = _tmp3_;
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_importer_start (_tmp4_);
#line 270 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp4_);
#line 2392 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_stop_importing (SpitDataImportsPluginHost* base)
{
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
	gboolean _tmp2_;
#line 273 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 274 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:274: WelcomeDataImportsHost.stop_importing(" \
" ): invoked.");
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_is_running (_tmp1_);
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 276 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp2_) {
#line 2417 "DataImportsPluginHost.c"
		SpitDataImportsDataImporter* _tmp3_;
		SpitDataImportsDataImporter* _tmp4_;
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp3_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp4_ = _tmp3_;
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_data_importer_stop (_tmp4_);
#line 277 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp4_);
#line 2428 "DataImportsPluginHost.c"
	}
#line 279 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_data_imports_host_clean_up (self);
#line 281 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->importing_halted = TRUE;
#line 2434 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_clean_up (SpitDataImportsWelcomeDataImportsHost* self)
{
#line 284 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_DATA_IMPORTS_HOST (self));
#line 2443 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_post_error (SpitDataImportsPluginHost* base,
                                                             GError* err)
{
	SpitDataImportsWelcomeDataImportsHost * self;
	const gchar* _tmp0_;
#line 289 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = err->message;
#line 290 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_post_error_message (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), _tmp0_);
#line 2459 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_post_error_message (SpitDataImportsPluginHost* base,
                                                                     const gchar* message)
{
	SpitDataImportsWelcomeDataImportsHost * self;
	gchar* msg = NULL;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsService* _tmp1_;
	SpitDataImportsService* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	SpitDataImportsDataImporter* _tmp6_;
	SpitDataImportsDataImporter* _tmp7_;
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->active_importer;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_data_importer_get_service (_tmp0_);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = g_strdup_printf (_ ("Importing from %s can’t continue because an error occurred:"), _tmp3_);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = _tmp4_;
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp2_);
#line 294 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	msg = _tmp5_;
#line 297 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:297: %s", msg);
#line 299 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 299 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp7_ = _tmp6_;
#line 299 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_data_importer_stop (_tmp7_);
#line 299 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp7_);
#line 304 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_data_imports_host_clean_up (self);
#line 293 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (msg);
#line 2511 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_install_dialog_pane (SpitDataImportsPluginHost* base,
                                                                      SpitDataImportsDialogPane* pane,
                                                                      SpitDataImportsPluginHostButtonMode button_mode)
{
	SpitDataImportsWelcomeDataImportsHost * self;
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 307 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_DIALOG_PANE (pane));
#line 2525 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_install_static_message_pane (SpitDataImportsPluginHost* base,
                                                                              const gchar* message,
                                                                              SpitDataImportsPluginHostButtonMode button_mode)
{
	SpitDataImportsWelcomeDataImportsHost * self;
#line 312 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 312 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 2539 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_install_library_selection_pane (SpitDataImportsPluginHost* base,
                                                                                 const gchar* welcome_message,
                                                                                 SpitDataImportsImportableLibrary** discovered_libraries,
                                                                                 int discovered_libraries_length1,
                                                                                 const gchar* file_select_label)
{
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsDataImporter* _tmp0_;
	SpitDataImportsDataImporter* _tmp1_;
	SpitDataImportsService* _tmp2_;
	SpitDataImportsService* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
#line 317 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 317 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (welcome_message != NULL);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = spit_data_imports_data_importer_get_service (_tmp1_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp5_ = g_strdup_printf ("WelcomeDataImportsHost: Installing library selection pane for %s", _tmp4_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp6_ = _tmp5_;
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:322: %s", _tmp6_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (_tmp6_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp3_);
#line 322 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (_tmp1_);
#line 323 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (discovered_libraries_length1 > 0) {
#line 2586 "DataImportsPluginHost.c"
		SpitDataImportsWelcomeImportMetaHost* _tmp7_;
		SpitDataImportsDataImporter* _tmp8_;
		SpitDataImportsDataImporter* _tmp9_;
		SpitDataImportsService* _tmp10_;
		SpitDataImportsService* _tmp11_;
		const gchar* _tmp12_;
		SpitDataImportsWelcomeImportServiceEntry* _tmp13_;
		SpitDataImportsWelcomeImportServiceEntry* _tmp14_;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp7_ = self->priv->meta_host;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp8_ = spit_data_imports_plugin_host_get_data_importer (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp9_ = _tmp8_;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp10_ = spit_data_imports_data_importer_get_service (_tmp9_);
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp11_ = _tmp10_;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp12_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp13_ = spit_data_imports_welcome_import_service_entry_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost), _tmp12_, discovered_libraries, discovered_libraries_length1);
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp14_ = _tmp13_;
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_welcome_import_meta_host_install_service_entry (_tmp7_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntry));
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp14_);
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp11_);
#line 324 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_tmp9_);
#line 2619 "DataImportsPluginHost.c"
	}
}


static void
spit_data_imports_welcome_data_imports_host_real_install_import_progress_pane (SpitDataImportsPluginHost* base,
                                                                               const gchar* message)
{
	SpitDataImportsWelcomeDataImportsHost * self;
#line 332 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 332 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (message != NULL);
#line 2633 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_update_import_progress_pane (SpitDataImportsPluginHost* base,
                                                                              gdouble progress,
                                                                              const gchar* progress_message)
{
	SpitDataImportsWelcomeDataImportsHost * self;
#line 338 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 2645 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_prepare_media_items_for_import (SpitDataImportsPluginHost* base,
                                                                                 SpitDataImportsImportableMediaItem** items,
                                                                                 int items_length1,
                                                                                 gdouble progress,
                                                                                 gdouble host_progress_delta,
                                                                                 const gchar* progress_message)
{
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsCoreImporter* _tmp0_;
#line 345 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->core_importer;
#line 351 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_prepare_media_items_for_import (_tmp0_, items, items_length1, progress, host_progress_delta, progress_message);
#line 2665 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_real_finalize_import (SpitDataImportsPluginHost* base,
                                                                  SpitDataImportsImportedItemsCountCallback report_imported_items_count,
                                                                  void* report_imported_items_count_target,
                                                                  const gchar* finalize_message)
{
	SpitDataImportsWelcomeDataImportsHost * self;
	SpitDataImportsCoreImporter* _tmp0_;
	SpitDataImportsCoreImporter* _tmp1_;
	gint _tmp2_;
	SpitDataImportsWelcomeImportMetaHost* _tmp3_;
#line 354 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->core_importer;
#line 358 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_core_importer_finalize_import (_tmp0_);
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = self->priv->core_importer;
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_->imported_items_count;
#line 359 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	report_imported_items_count (_tmp2_, report_imported_items_count_target);
#line 360 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = self->priv->meta_host;
#line 360 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_import_meta_host_finalize_import (_tmp3_, self);
#line 2696 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_class_init (SpitDataImportsWelcomeDataImportsHostClass * klass)
{
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_data_imports_host_parent_class = g_type_class_peek_parent (klass);
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsWelcomeDataImportsHostPrivate));
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (klass)->finalize = spit_data_imports_welcome_data_imports_host_finalize;
#line 2709 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_spit_data_imports_plugin_host_interface_init (SpitDataImportsPluginHostIface * iface)
{
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_data_imports_host_spit_data_imports_plugin_host_parent_iface = g_type_interface_peek_parent (iface);
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->get_data_importer = (SpitDataImportsDataImporter* (*) (SpitDataImportsPluginHost *)) spit_data_imports_welcome_data_imports_host_real_get_data_importer;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->start_importing = (void (*) (SpitDataImportsPluginHost *)) spit_data_imports_welcome_data_imports_host_real_start_importing;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->stop_importing = (void (*) (SpitDataImportsPluginHost *)) spit_data_imports_welcome_data_imports_host_real_stop_importing;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->post_error = (void (*) (SpitDataImportsPluginHost *, GError*)) spit_data_imports_welcome_data_imports_host_real_post_error;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->post_error_message = (void (*) (SpitDataImportsPluginHost *, const gchar*)) spit_data_imports_welcome_data_imports_host_real_post_error_message;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_dialog_pane = (void (*) (SpitDataImportsPluginHost *, SpitDataImportsDialogPane*, SpitDataImportsPluginHostButtonMode)) spit_data_imports_welcome_data_imports_host_real_install_dialog_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_static_message_pane = (void (*) (SpitDataImportsPluginHost *, const gchar*, SpitDataImportsPluginHostButtonMode)) spit_data_imports_welcome_data_imports_host_real_install_static_message_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_library_selection_pane = (void (*) (SpitDataImportsPluginHost *, const gchar*, SpitDataImportsImportableLibrary**, int, const gchar*)) spit_data_imports_welcome_data_imports_host_real_install_library_selection_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->install_import_progress_pane = (void (*) (SpitDataImportsPluginHost *, const gchar*)) spit_data_imports_welcome_data_imports_host_real_install_import_progress_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->update_import_progress_pane = (void (*) (SpitDataImportsPluginHost *, gdouble, const gchar*)) spit_data_imports_welcome_data_imports_host_real_update_import_progress_pane;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->prepare_media_items_for_import = (void (*) (SpitDataImportsPluginHost *, SpitDataImportsImportableMediaItem**, int, gdouble, gdouble, const gchar*)) spit_data_imports_welcome_data_imports_host_real_prepare_media_items_for_import;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->finalize_import = (void (*) (SpitDataImportsPluginHost *, SpitDataImportsImportedItemsCountCallback, void*, const gchar*)) spit_data_imports_welcome_data_imports_host_real_finalize_import;
#line 2742 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_instance_init (SpitDataImportsWelcomeDataImportsHost * self)
{
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_WELCOME_DATA_IMPORTS_HOST_GET_PRIVATE (self);
#line 248 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->active_importer = NULL;
#line 249 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->importing_halted = FALSE;
#line 2755 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_data_imports_host_finalize (GObject * obj)
{
	SpitDataImportsWelcomeDataImportsHost * self;
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_WELCOME_DATA_IMPORTS_HOST, SpitDataImportsWelcomeDataImportsHost);
#line 248 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->active_importer);
#line 250 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_spit_data_imports_core_importer_unref0 (self->priv->core_importer);
#line 244 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (spit_data_imports_welcome_data_imports_host_parent_class)->finalize (obj);
#line 2771 "DataImportsPluginHost.c"
}


GType
spit_data_imports_welcome_data_imports_host_get_type (void)
{
	static volatile gsize spit_data_imports_welcome_data_imports_host_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_welcome_data_imports_host_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsWelcomeDataImportsHostClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_welcome_data_imports_host_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsWelcomeDataImportsHost), 0, (GInstanceInitFunc) spit_data_imports_welcome_data_imports_host_instance_init, NULL };
		static const GInterfaceInfo spit_data_imports_plugin_host_info = { (GInterfaceInitFunc) spit_data_imports_welcome_data_imports_host_spit_data_imports_plugin_host_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType spit_data_imports_welcome_data_imports_host_type_id;
		spit_data_imports_welcome_data_imports_host_type_id = g_type_register_static (PLUGINS_TYPE_STANDARD_HOST_INTERFACE, "SpitDataImportsWelcomeDataImportsHost", &g_define_type_info, 0);
		g_type_add_interface_static (spit_data_imports_welcome_data_imports_host_type_id, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, &spit_data_imports_plugin_host_info);
		g_once_init_leave (&spit_data_imports_welcome_data_imports_host_type_id__volatile, spit_data_imports_welcome_data_imports_host_type_id);
	}
	return spit_data_imports_welcome_data_imports_host_type_id__volatile;
}


static SpitDataImportsImportableLibrary**
_vala_array_dup21 (SpitDataImportsImportableLibrary** self,
                   int length)
{
	SpitDataImportsImportableLibrary** result;
	int i;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = g_new0 (SpitDataImportsImportableLibrary*, length + 1);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	for (i = 0; i < length; i++) {
#line 2801 "DataImportsPluginHost.c"
		SpitDataImportsImportableLibrary* _tmp0_;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		result[i] = _tmp0_;
#line 2807 "DataImportsPluginHost.c"
	}
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 2811 "DataImportsPluginHost.c"
}


SpitDataImportsWelcomeImportServiceEntry*
spit_data_imports_welcome_import_service_entry_construct (GType object_type,
                                                          SpitDataImportsPluginHost* host,
                                                          const gchar* pluggable_name,
                                                          SpitDataImportsImportableLibrary** discovered_libraries,
                                                          int discovered_libraries_length1)
{
	SpitDataImportsWelcomeImportServiceEntry * self = NULL;
	SpitDataImportsPluginHost* _tmp0_;
	gchar* _tmp1_;
	SpitDataImportsImportableLibrary** _tmp2_;
	gint _tmp2__length1;
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (SPIT_DATA_IMPORTS_IS_PLUGIN_HOST (host), NULL);
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (pluggable_name != NULL, NULL);
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsWelcomeImportServiceEntry*) g_object_new (object_type, NULL);
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = _g_object_ref0 (host);
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->host);
#line 376 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->host = _tmp0_;
#line 377 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = g_strdup (pluggable_name);
#line 377 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (self->priv->pluggable_name);
#line 377 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->pluggable_name = _tmp1_;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = (discovered_libraries != NULL) ? _vala_array_dup21 (discovered_libraries, discovered_libraries_length1) : ((gpointer) discovered_libraries);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2__length1 = discovered_libraries_length1;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->discovered_libraries = (_vala_array_free (self->priv->discovered_libraries, self->priv->discovered_libraries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->discovered_libraries = _tmp2_;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->discovered_libraries_length1 = _tmp2__length1;
#line 378 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->_discovered_libraries_size_ = self->priv->discovered_libraries_length1;
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 2859 "DataImportsPluginHost.c"
}


SpitDataImportsWelcomeImportServiceEntry*
spit_data_imports_welcome_import_service_entry_new (SpitDataImportsPluginHost* host,
                                                    const gchar* pluggable_name,
                                                    SpitDataImportsImportableLibrary** discovered_libraries,
                                                    int discovered_libraries_length1)
{
#line 372 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_welcome_import_service_entry_construct (SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, host, pluggable_name, discovered_libraries, discovered_libraries_length1);
#line 2871 "DataImportsPluginHost.c"
}


static gchar*
spit_data_imports_welcome_import_service_entry_real_get_service_name (WelcomeServiceEntry* base)
{
	SpitDataImportsWelcomeImportServiceEntry * self;
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 381 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntry);
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->pluggable_name;
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp1_;
#line 382 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 2892 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_import_service_entry_real_execute (WelcomeServiceEntry* base)
{
	SpitDataImportsWelcomeImportServiceEntry * self;
	SpitDataImportsImportableLibrary** _tmp0_;
	gint _tmp0__length1;
#line 385 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntry);
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = self->priv->discovered_libraries;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0__length1 = self->priv->discovered_libraries_length1;
#line 2908 "DataImportsPluginHost.c"
	{
		SpitDataImportsImportableLibrary** library_collection = NULL;
		gint library_collection_length1 = 0;
		gint _library_collection_size_ = 0;
		gint library_it = 0;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		library_collection = _tmp0_;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		library_collection_length1 = _tmp0__length1;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		for (library_it = 0; library_it < _tmp0__length1; library_it = library_it + 1) {
#line 2920 "DataImportsPluginHost.c"
			SpitDataImportsImportableLibrary* _tmp1_;
			SpitDataImportsImportableLibrary* library = NULL;
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp1_ = _g_object_ref0 (library_collection[library_it]);
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			library = _tmp1_;
#line 2927 "DataImportsPluginHost.c"
			{
				SpitDataImportsPluginHost* _tmp2_;
				SpitDataImportsDataImporter* _tmp3_;
				SpitDataImportsDataImporter* _tmp4_;
				SpitDataImportsImportableLibrary* _tmp5_;
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp2_ = self->priv->host;
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp3_ = spit_data_imports_plugin_host_get_data_importer (_tmp2_);
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp4_ = _tmp3_;
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp5_ = library;
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				spit_data_imports_data_importer_on_library_selected (_tmp4_, _tmp5_);
#line 387 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (_tmp4_);
#line 386 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (library);
#line 2947 "DataImportsPluginHost.c"
			}
		}
	}
}


static void
spit_data_imports_welcome_import_service_entry_class_init (SpitDataImportsWelcomeImportServiceEntryClass * klass)
{
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_import_service_entry_parent_class = g_type_class_peek_parent (klass);
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsWelcomeImportServiceEntryPrivate));
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (klass)->finalize = spit_data_imports_welcome_import_service_entry_finalize;
#line 2963 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_import_service_entry_welcome_service_entry_interface_init (WelcomeServiceEntryIface * iface)
{
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_import_service_entry_welcome_service_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->get_service_name = (gchar* (*) (WelcomeServiceEntry *)) spit_data_imports_welcome_import_service_entry_real_get_service_name;
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	iface->execute = (void (*) (WelcomeServiceEntry *)) spit_data_imports_welcome_import_service_entry_real_execute;
#line 2976 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_import_service_entry_instance_init (SpitDataImportsWelcomeImportServiceEntry * self)
{
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_WELCOME_IMPORT_SERVICE_ENTRY_GET_PRIVATE (self);
#line 2985 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_import_service_entry_finalize (GObject * obj)
{
	SpitDataImportsWelcomeImportServiceEntry * self;
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_SERVICE_ENTRY, SpitDataImportsWelcomeImportServiceEntry);
#line 368 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (self->priv->pluggable_name);
#line 369 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->discovered_libraries = (_vala_array_free (self->priv->discovered_libraries, self->priv->discovered_libraries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 370 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->host);
#line 367 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (spit_data_imports_welcome_import_service_entry_parent_class)->finalize (obj);
#line 3003 "DataImportsPluginHost.c"
}


GType
spit_data_imports_welcome_import_service_entry_get_type (void)
{
	static volatile gsize spit_data_imports_welcome_import_service_entry_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_welcome_import_service_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsWelcomeImportServiceEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_welcome_import_service_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsWelcomeImportServiceEntry), 0, (GInstanceInitFunc) spit_data_imports_welcome_import_service_entry_instance_init, NULL };
		static const GInterfaceInfo welcome_service_entry_info = { (GInterfaceInitFunc) spit_data_imports_welcome_import_service_entry_welcome_service_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType spit_data_imports_welcome_import_service_entry_type_id;
		spit_data_imports_welcome_import_service_entry_type_id = g_type_register_static (G_TYPE_OBJECT, "SpitDataImportsWelcomeImportServiceEntry", &g_define_type_info, 0);
		g_type_add_interface_static (spit_data_imports_welcome_import_service_entry_type_id, TYPE_WELCOME_SERVICE_ENTRY, &welcome_service_entry_info);
		g_once_init_leave (&spit_data_imports_welcome_import_service_entry_type_id__volatile, spit_data_imports_welcome_import_service_entry_type_id);
	}
	return spit_data_imports_welcome_import_service_entry_type_id__volatile;
}


SpitDataImportsWelcomeImportMetaHost*
spit_data_imports_welcome_import_meta_host_construct (GType object_type,
                                                      WelcomeDialog* dialog)
{
	SpitDataImportsWelcomeImportMetaHost * self = NULL;
	WelcomeDialog* _tmp0_;
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_val_if_fail (IS_WELCOME_DIALOG (dialog), NULL);
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = (SpitDataImportsWelcomeImportMetaHost*) g_object_new (object_type, NULL);
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = _g_object_ref0 (dialog);
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->dialog);
#line 396 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv->dialog = _tmp0_;
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return self;
#line 3041 "DataImportsPluginHost.c"
}


SpitDataImportsWelcomeImportMetaHost*
spit_data_imports_welcome_import_meta_host_new (WelcomeDialog* dialog)
{
#line 395 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return spit_data_imports_welcome_import_meta_host_construct (SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, dialog);
#line 3050 "DataImportsPluginHost.c"
}


void
spit_data_imports_welcome_import_meta_host_start (SpitDataImportsWelcomeImportMetaHost* self)
{
	SpitDataImportsService** services = NULL;
	gint _tmp0_;
	SpitDataImportsService** _tmp1_;
	gint services_length1;
	gint _services_size_;
	SpitDataImportsService** _tmp2_;
	gint _tmp2__length1;
#line 399 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST (self));
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_load_all_services (&_tmp0_);
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	services = _tmp1_;
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	services_length1 = _tmp0_;
#line 400 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_services_size_ = services_length1;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = services;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2__length1 = services_length1;
#line 3078 "DataImportsPluginHost.c"
	{
		SpitDataImportsService** service_collection = NULL;
		gint service_collection_length1 = 0;
		gint _service_collection_size_ = 0;
		gint service_it = 0;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		service_collection = _tmp2_;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		service_collection_length1 = _tmp2__length1;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		for (service_it = 0; service_it < _tmp2__length1; service_it = service_it + 1) {
#line 3090 "DataImportsPluginHost.c"
			SpitDataImportsService* _tmp3_;
			SpitDataImportsService* service = NULL;
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp3_ = _g_object_ref0 (service_collection[service_it]);
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			service = _tmp3_;
#line 3097 "DataImportsPluginHost.c"
			{
				SpitDataImportsWelcomeDataImportsHost* host = NULL;
				SpitDataImportsService* _tmp4_;
				SpitDataImportsWelcomeDataImportsHost* _tmp5_;
				SpitDataImportsWelcomeDataImportsHost* _tmp6_;
#line 402 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp4_ = service;
#line 402 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp5_ = spit_data_imports_welcome_data_imports_host_new (_tmp4_, self);
#line 402 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				host = _tmp5_;
#line 403 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp6_ = host;
#line 403 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				spit_data_imports_plugin_host_start_importing (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (host);
#line 401 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (service);
#line 3117 "DataImportsPluginHost.c"
			}
		}
	}
#line 399 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	services = (_vala_array_free (services, services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 3123 "DataImportsPluginHost.c"
}


void
spit_data_imports_welcome_import_meta_host_finalize_import (SpitDataImportsWelcomeImportMetaHost* self,
                                                            SpitDataImportsWelcomeDataImportsHost* host)
{
#line 407 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST (self));
#line 407 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_DATA_IMPORTS_HOST (host));
#line 408 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_plugin_host_stop_importing (G_TYPE_CHECK_INSTANCE_CAST (host, SPIT_DATA_IMPORTS_TYPE_PLUGIN_HOST, SpitDataImportsPluginHost));
#line 3137 "DataImportsPluginHost.c"
}


void
spit_data_imports_welcome_import_meta_host_install_service_entry (SpitDataImportsWelcomeImportMetaHost* self,
                                                                  WelcomeServiceEntry* entry)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	WelcomeDialog* _tmp4_;
#line 411 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST (self));
#line 411 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (IS_WELCOME_SERVICE_ENTRY (entry));
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = welcome_service_entry_get_service_name (entry);
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = _tmp0_;
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = g_strdup_printf ("WelcomeImportMetaHost: Installing service entry for %s", _tmp1_);
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = _tmp2_;
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:412: %s", _tmp3_);
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (_tmp3_);
#line 412 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_free0 (_tmp1_);
#line 413 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = self->priv->dialog;
#line 413 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	welcome_dialog_install_service_entry (_tmp4_, entry);
#line 3172 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_import_meta_host_class_init (SpitDataImportsWelcomeImportMetaHostClass * klass)
{
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	spit_data_imports_welcome_import_meta_host_parent_class = g_type_class_peek_parent (klass);
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_type_class_add_private (klass, sizeof (SpitDataImportsWelcomeImportMetaHostPrivate));
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (klass)->finalize = spit_data_imports_welcome_import_meta_host_finalize;
#line 3185 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_import_meta_host_instance_init (SpitDataImportsWelcomeImportMetaHost * self)
{
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self->priv = SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_GET_PRIVATE (self);
#line 3194 "DataImportsPluginHost.c"
}


static void
spit_data_imports_welcome_import_meta_host_finalize (GObject * obj)
{
	SpitDataImportsWelcomeImportMetaHost * self;
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHost);
#line 393 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (self->priv->dialog);
#line 392 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	G_OBJECT_CLASS (spit_data_imports_welcome_import_meta_host_parent_class)->finalize (obj);
#line 3208 "DataImportsPluginHost.c"
}


GType
spit_data_imports_welcome_import_meta_host_get_type (void)
{
	static volatile gsize spit_data_imports_welcome_import_meta_host_type_id__volatile = 0;
	if (g_once_init_enter (&spit_data_imports_welcome_import_meta_host_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SpitDataImportsWelcomeImportMetaHostClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spit_data_imports_welcome_import_meta_host_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpitDataImportsWelcomeImportMetaHost), 0, (GInstanceInitFunc) spit_data_imports_welcome_import_meta_host_instance_init, NULL };
		GType spit_data_imports_welcome_import_meta_host_type_id;
		spit_data_imports_welcome_import_meta_host_type_id = g_type_register_static (G_TYPE_OBJECT, "SpitDataImportsWelcomeImportMetaHost", &g_define_type_info, 0);
		g_once_init_leave (&spit_data_imports_welcome_import_meta_host_type_id__volatile, spit_data_imports_welcome_import_meta_host_type_id);
	}
	return spit_data_imports_welcome_import_meta_host_type_id__volatile;
}


SpitDataImportsService**
spit_data_imports_load_all_services (int* result_length1)
{
	SpitDataImportsService** result = NULL;
	gint _tmp0_;
	SpitDataImportsService** _tmp1_;
	SpitDataImportsService** _tmp2_;
	gint _tmp2__length1;
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_data_imports_load_services (TRUE, &_tmp0_);
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2__length1 = _tmp0_;
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (result_length1) {
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*result_length1 = _tmp2__length1;
#line 3244 "DataImportsPluginHost.c"
	}
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp2_;
#line 418 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3250 "DataImportsPluginHost.c"
}


static void
_vala_array_add71 (SpitDataImportsService** * array,
                   int* length,
                   int* size,
                   SpitDataImportsService* value)
{
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if ((*length) == (*size)) {
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*array = g_renew (SpitDataImportsService*, *array, (*size) + 1);
#line 3266 "DataImportsPluginHost.c"
	}
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	(*array)[(*length)++] = value;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	(*array)[*length] = NULL;
#line 3272 "DataImportsPluginHost.c"
}


static gint
__lambda25_ (void* a,
             void* b)
{
	gint result = 0;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (*((SpitDataImportsService**) a), SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (*((SpitDataImportsService**) b), SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = utf8_cs_compare (_tmp0_, _tmp1_);
#line 453 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3291 "DataImportsPluginHost.c"
}


static gint
___lambda25____compar_fn_t (void* key1,
                            void* key2)
{
	gint result;
	result = __lambda25_ (key1, key2);
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3303 "DataImportsPluginHost.c"
}


SpitDataImportsService**
spit_data_imports_load_services (gboolean load_all,
                                 int* result_length1)
{
	SpitDataImportsService** result = NULL;
	SpitDataImportsService** loaded_services = NULL;
	SpitDataImportsService** _tmp0_;
	gint loaded_services_length1;
	gint _loaded_services_size_;
	GeeCollection* pluggables = NULL;
	GeeCollection* _tmp1_;
	GeeCollection* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	SpitDataImportsService** _tmp23_;
	gint _tmp23__length1;
	SpitDataImportsService** _tmp24_;
	gint _tmp24__length1;
	SpitDataImportsService** _tmp25_;
	gint _tmp25__length1;
#line 422 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = g_new0 (SpitDataImportsService*, 0 + 1);
#line 422 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	loaded_services = _tmp0_;
#line 422 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	loaded_services_length1 = 0;
#line 422 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_loaded_services_size_ = loaded_services_length1;
#line 425 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = plugins_get_pluggables_for_type (SPIT_DATA_IMPORTS_TYPE_SERVICE, NULL, NULL, NULL, load_all);
#line 425 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	pluggables = _tmp1_;
#line 429 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = pluggables;
#line 429 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp3_ = gee_collection_get_size (_tmp2_);
#line 429 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp4_ = _tmp3_;
#line 429 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_debug ("DataImportsPluginHost.vala:429: DataImportsDialog: discovered %d plugg" \
"able data import services.", _tmp4_);
#line 3347 "DataImportsPluginHost.c"
	{
		GeeIterator* _pluggable_it = NULL;
		GeeCollection* _tmp5_;
		GeeIterator* _tmp6_;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp5_ = pluggables;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp6_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_ITERABLE, GeeIterable));
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_pluggable_it = _tmp6_;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		while (TRUE) {
#line 3360 "DataImportsPluginHost.c"
			GeeIterator* _tmp7_;
			SpitPluggable* pluggable = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			gint pluggable_interface = 0;
			SpitPluggable* _tmp10_;
			gint _tmp11_;
			SpitDataImportsService* service = NULL;
			SpitPluggable* _tmp16_;
			SpitDataImportsService* _tmp17_;
			SpitDataImportsService* _tmp18_;
			const gchar* _tmp19_;
			SpitDataImportsService** _tmp20_;
			gint _tmp20__length1;
			SpitDataImportsService* _tmp21_;
			SpitDataImportsService* _tmp22_;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp7_ = _pluggable_it;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			if (!gee_iterator_next (_tmp7_)) {
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				break;
#line 3383 "DataImportsPluginHost.c"
			}
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp8_ = _pluggable_it;
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			pluggable = (SpitPluggable*) _tmp9_;
#line 432 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp10_ = pluggable;
#line 432 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			pluggable_interface = spit_pluggable_get_pluggable_interface (_tmp10_, SPIT_DATA_IMPORTS_CURRENT_INTERFACE, SPIT_DATA_IMPORTS_CURRENT_INTERFACE);
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp11_ = pluggable_interface;
#line 434 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			if (_tmp11_ != SPIT_DATA_IMPORTS_CURRENT_INTERFACE) {
#line 3399 "DataImportsPluginHost.c"
				SpitPluggable* _tmp12_;
				gchar* _tmp13_;
				gchar* _tmp14_;
				gint _tmp15_;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp12_ = pluggable;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp13_ = plugins_get_pluggable_module_id (_tmp12_);
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp14_ = _tmp13_;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp15_ = pluggable_interface;
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				g_warning ("DataImportsPluginHost.vala:435: Unable to load data import plugin %s: " \
"reported interface %d.", _tmp14_, _tmp15_);
#line 435 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_free0 (_tmp14_);
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_g_object_unref0 (pluggable);
#line 438 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				continue;
#line 3420 "DataImportsPluginHost.c"
			}
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp16_ = pluggable;
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, SPIT_DATA_IMPORTS_TYPE_SERVICE, SpitDataImportsService));
#line 441 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			service = _tmp17_;
#line 444 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp18_ = service;
#line 444 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp19_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 444 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			g_debug ("DataImportsPluginHost.vala:444: DataImportsDialog: discovered pluggabl" \
"e data import service '%s'.", _tmp19_);
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp20_ = loaded_services;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp20__length1 = loaded_services_length1;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp21_ = service;
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp22_ = _g_object_ref0 (_tmp21_);
#line 447 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_vala_array_add71 (&loaded_services, &loaded_services_length1, &_loaded_services_size_, _tmp22_);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_g_object_unref0 (service);
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_g_object_unref0 (pluggable);
#line 3448 "DataImportsPluginHost.c"
		}
#line 431 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_g_object_unref0 (_pluggable_it);
#line 3452 "DataImportsPluginHost.c"
	}
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp23_ = loaded_services;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp23__length1 = loaded_services_length1;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp24_ = loaded_services;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp24__length1 = loaded_services_length1;
#line 452 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	qsort (_tmp23_, (gsize) _tmp24__length1, (gsize) sizeof (SpitDataImportsService*), ___lambda25____compar_fn_t);
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp25_ = loaded_services;
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp25__length1 = loaded_services_length1;
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (result_length1) {
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		*result_length1 = _tmp25__length1;
#line 3472 "DataImportsPluginHost.c"
	}
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = _tmp25_;
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_g_object_unref0 (pluggables);
#line 457 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3480 "DataImportsPluginHost.c"
}


void
spit_data_imports_data_import_reporter (ImportManifest* manifest,
                                        BatchImportRoll* import_roll)
{
	GeeList* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 462 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (IS_IMPORT_MANIFEST (manifest));
#line 462 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	g_return_if_fail (IS_BATCH_IMPORT_ROLL (import_roll));
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp0_ = manifest->all;
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp1_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection));
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	_tmp2_ = _tmp1_;
#line 463 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	if (_tmp2_ > 0) {
#line 3503 "DataImportsPluginHost.c"
		ImportManifest* _tmp3_;
#line 464 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp3_ = spit_data_imports_meta_manifest;
#line 464 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		if (_tmp3_ == NULL) {
#line 3509 "DataImportsPluginHost.c"
			ImportManifest* _tmp4_;
#line 465 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp4_ = import_manifest_new (NULL, NULL);
#line 465 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_import_manifest_unref0 (spit_data_imports_meta_manifest);
#line 465 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			spit_data_imports_meta_manifest = _tmp4_;
#line 3517 "DataImportsPluginHost.c"
		}
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp5_;
			GeeList* _tmp6_;
			gint _result_size = 0;
			GeeList* _tmp7_;
			gint _tmp8_;
			gint _tmp9_;
			gint _result_index = 0;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp5_ = manifest->all;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp6_ = _g_object_ref0 (_tmp5_);
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_result_list = _tmp6_;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp7_ = _result_list;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp8_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_tmp9_ = _tmp8_;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_result_size = _tmp9_;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_result_index = -1;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			while (TRUE) {
#line 3546 "DataImportsPluginHost.c"
				gint _tmp10_;
				gint _tmp11_;
				gint _tmp12_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp13_;
				gint _tmp14_;
				gpointer _tmp15_;
				ImportManifest* _tmp16_;
				BatchImportResult* _tmp17_;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp10_ = _result_index;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_result_index = _tmp10_ + 1;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp11_ = _result_index;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp12_ = _result_size;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				if (!(_tmp11_ < _tmp12_)) {
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
					break;
#line 3568 "DataImportsPluginHost.c"
				}
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp13_ = _result_list;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp14_ = _result_index;
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp15_ = gee_list_get (_tmp13_, _tmp14_);
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_result_ = (BatchImportResult*) _tmp15_;
#line 467 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp16_ = spit_data_imports_meta_manifest;
#line 467 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_tmp17_ = _result_;
#line 467 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				import_manifest_add_result (_tmp16_, _tmp17_);
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
				_batch_import_result_unref0 (_result_);
#line 3586 "DataImportsPluginHost.c"
			}
#line 466 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
			_g_object_unref0 (_result_list);
#line 3590 "DataImportsPluginHost.c"
		}
	} else {
		ImportManifest* _tmp18_;
#line 470 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		data_imports_ui_data_imports_dialog_terminate_instance ();
#line 471 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_tmp18_ = spit_data_imports_meta_manifest;
#line 471 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		import_ui_report_manifest (_tmp18_, TRUE, NULL);
#line 472 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		_import_manifest_unref0 (spit_data_imports_meta_manifest);
#line 472 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
		spit_data_imports_meta_manifest = NULL;
#line 3604 "DataImportsPluginHost.c"
	}
}


gint64
spit_data_imports_import_job_comparator (void* a,
                                         void* b)
{
	gint64 result = 0LL;
#line 477 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	result = (gint64) (spit_data_imports_data_import_job_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST ((SpitDataImportsDataImportJob*) a, SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJob)) - spit_data_imports_data_import_job_get_exposure_time (G_TYPE_CHECK_INSTANCE_CAST ((SpitDataImportsDataImportJob*) b, SPIT_DATA_IMPORTS_TYPE_DATA_IMPORT_JOB, SpitDataImportsDataImportJob)));
#line 477 "/home/jens/Source/shotwell/src/data_imports/DataImportsPluginHost.vala"
	return result;
#line 3618 "DataImportsPluginHost.c"
}


static void
_vala_array_destroy (gpointer array,
                     gint array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void
_vala_array_free (gpointer array,
                  gint array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



